View Source ExOpenAI.Codegen.DocsParser (ex_openai.ex v2.0.0-beta2)

Parser for OpenAPI YAML documentation.

Provides typed structs for components and paths to improve visibility and type safety when working with the OpenAPI specification.

Summary

Functions

Parses OpenAPI YAML documentation and returns typed structs.

Types

Functions

@spec get_documentation(String.t()) :: ExOpenAI.Codegen.DocsParser.Documentation.t()

Parses OpenAPI YAML documentation and returns typed structs.