View Source ExOpenAI.Components.ApplyPatchDeleteFileOperationParam (ex_openai.ex v2.0.0-beta2)

Instruction for deleting an existing file via the apply_patch tool.

Fields

  • :path - required - String.t()
    Path of the file to delete relative to the workspace root.
    Constraints: minLength: 1

  • :type - required - :delete_file
    The operation type. Always delete_file.
    Allowed values: "delete_file"
    Default: "delete_file"

Summary

Types

@type t() :: %ExOpenAI.Components.ApplyPatchDeleteFileOperationParam{
  path: String.t(),
  type: :delete_file
}