View Source ExOpenAI.Components.ApplyPatchToolCallOutput (ex_openai.ex v2.0.0-beta2)

The output emitted by an apply patch tool call.

Fields

  • :call_id - required - String.t()
    The unique ID of the apply patch tool call generated by the model.

  • :created_by - optional - String.t()
    The ID of the entity that created this tool call output.

  • :id - required - String.t()
    The unique ID of the apply patch tool call output. Populated when this item is returned via API.

  • :output - optional - String.t() | any()

  • :status - required - ExOpenAI.Components.ApplyPatchCallOutputStatus.t()
    The status of the apply patch tool call output. One of completed or failed.

  • :type - required - :apply_patch_call_output
    The type of the item. Always apply_patch_call_output.
    Allowed values: "apply_patch_call_output"
    Default: "apply_patch_call_output"

Summary

Types

@type t() :: %ExOpenAI.Components.ApplyPatchToolCallOutput{
  call_id: String.t(),
  created_by: String.t() | nil,
  id: String.t(),
  output: (String.t() | any()) | nil,
  status: ExOpenAI.Components.ApplyPatchCallOutputStatus.t(),
  type: :apply_patch_call_output
}