View Source ExOpenAI.Components.ApplyPatchUpdateFileOperationParam (ex_openai.ex v2.0.0-beta2)

Instruction for updating an existing file via the apply_patch tool.

Fields

  • :diff - required - String.t()
    Unified diff content to apply to the existing file.
    Constraints: maxLength: 10485760

  • :path - required - String.t()
    Path of the file to update relative to the workspace root.
    Constraints: minLength: 1

  • :type - required - :update_file
    The operation type. Always update_file.
    Allowed values: "update_file"
    Default: "update_file"

Summary

Types

@type t() :: %ExOpenAI.Components.ApplyPatchUpdateFileOperationParam{
  diff: String.t(),
  path: String.t(),
  type: :update_file
}