View Source ExOpenAI.Components.AssistantsNamedToolChoice (ex_openai.ex v2.0.0-beta2)

Specifies a tool the model should use. Use to force the model to call a specific tool.

Fields

  • :function - optional - {:%{}, [], [{{:required, [], [:name]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}

  • :type - required - :function | :code_interpreter | :file_search
    The type of the tool. If type is function, the function name must be set
    Allowed values: "function", "code_interpreter", "file_search"

Summary

Types

@type t() :: %ExOpenAI.Components.AssistantsNamedToolChoice{
  function: %{name: String.t()} | nil,
  type: (:function | :code_interpreter) | :file_search
}