View Source ExOpenAI.Components.AutoCodeInterpreterToolParam (ex_openai.ex v2.0.0-beta2)

Configuration for a code interpreter container. Optionally specify the IDs of the files to run the code on.

Fields

  • :file_ids - optional - [String.t()]
    An optional list of uploaded files to make available to your code.
    Constraints: maxItems: 50

  • :memory_limit - optional - ExOpenAI.Components.ContainerMemoryLimit.t() | any()

  • :network_policy - optional - ExOpenAI.Components.ContainerNetworkPolicyDisabledParam.t() | ExOpenAI.Components.ContainerNetworkPolicyAllowlistParam.t()
    Network access policy for the container.

  • :type - required - :auto
    Always auto.
    Allowed values: "auto"
    Default: "auto"

Summary

Types

@type t() :: %ExOpenAI.Components.AutoCodeInterpreterToolParam{
  file_ids: [String.t()] | nil,
  memory_limit: (ExOpenAI.Components.ContainerMemoryLimit.t() | any()) | nil,
  network_policy:
    (ExOpenAI.Components.ContainerNetworkPolicyDisabledParam.t()
     | ExOpenAI.Components.ContainerNetworkPolicyAllowlistParam.t())
    | nil,
  type: :auto
}