View Source ExOpenAI.Components.ChatCompletionMessageToolCalls (ex_openai.ex v2.0.0-beta)
The tool calls generated by the model, such as function calls.
Type
[any() | any()]
The tool calls generated by the model, such as function calls.
[any() | any()]