View Source ExOpenAI.Components.ChatCompletionNamedToolChoiceCustom (ex_openai.ex v2.0.0-beta2)

Specifies a tool the model should use. Use to force the model to call a specific custom tool.

Fields

  • :custom - required - {:%{}, [], [{{:required, [], [:name]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}

  • :type - required - :custom
    For custom tool calling, the type is always custom.
    Allowed values: "custom"

Summary

Types

@type t() :: %ExOpenAI.Components.ChatCompletionNamedToolChoiceCustom{
  custom: %{name: String.t()},
  type: :custom
}