View Source ExOpenAI.Components.ChatCompletionRequestAssistantMessage (ex_openai.ex v2.0.0-beta)
Messages sent by the model in response to user messages.
Fields
:audio- optional -{:%{}, [], [{{:required, [], [:id]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]} | any():content- optional -String.t() | [any()] | any():function_call- optional -{:%{}, [], [{{:required, [], [:arguments]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:required, [], [:name]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]} | any():name- optional -String.t()
An optional name for the participant. Provides the model information to differentiate between participants of the same role.:refusal- optional -String.t() | any():role- required -:assistant
The role of the messages author, in this caseassistant.
Allowed values:"assistant":tool_calls- optional -any()
Summary
Types
@type t() :: %ExOpenAI.Components.ChatCompletionRequestAssistantMessage{ audio: (%{id: String.t()} | any()) | nil, content: ((String.t() | [ ExOpenAI.Components.ChatCompletionRequestAssistantMessageContentPart.t() ]) | any()) | nil, function_call: (%{arguments: String.t(), name: String.t()} | any()) | nil, name: String.t() | nil, refusal: (String.t() | any()) | nil, role: :assistant, tool_calls: ExOpenAI.Components.ChatCompletionMessageToolCalls.t() | nil }