View Source ExOpenAI.Components.ChatCompletionRequestDeveloperMessage (ex_openai.ex v2.0.0-beta2)

Developer-provided instructions that the model should follow, regardless of messages sent by the user. With o1 models and newer, developer messages replace the previous system messages.

Fields

  • :content - required - String.t() | [ExOpenAI.Components.ChatCompletionRequestMessageContentPartText.t()]
    The contents of the developer message.

  • :name - optional - String.t()
    An optional name for the participant. Provides the model information to differentiate between participants of the same role.

  • :role - required - :developer
    The role of the messages author, in this case developer.
    Allowed values: "developer"

Summary

Types

@type t() :: %ExOpenAI.Components.ChatCompletionRequestDeveloperMessage{
  content:
    String.t()
    | [ExOpenAI.Components.ChatCompletionRequestMessageContentPartText.t()],
  name: String.t() | nil,
  role: :developer
}