View Source ExOpenAI.Components.ChatCompletionRequestUserMessage (ex_openai.ex v2.0.0-beta2)
Messages sent by an end user, containing prompts or additional context information.
Fields
:content- required -String.t() | [ExOpenAI.Components.ChatCompletionRequestUserMessageContentPart.t()]
The contents of the user message.:name- optional -String.t()
An optional name for the participant. Provides the model information to differentiate between participants of the same role.:role- required -:user
The role of the messages author, in this caseuser.
Allowed values:"user"
Summary
Types
@type t() :: %ExOpenAI.Components.ChatCompletionRequestUserMessage{ content: String.t() | [ExOpenAI.Components.ChatCompletionRequestUserMessageContentPart.t()], name: String.t() | nil, role: :user }