View Source ExOpenAI.Components.ChatCompletionTokenLogprob (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema ChatCompletionTokenLogprob.
Fields
:bytes- required -[integer()] | any():logprob- required -number()
The log probability of this token, if it is within the top 20 most likely tokens. Otherwise, the value-9999.0is used to signify that the token is very unlikely.:token- required -String.t()
The token.:top_logprobs- required -[{:%{}, [], [{{:required, [], [:bytes]}, {:|, [], [{:list, [], [{:integer, [], []}]}, {:any, [], []}]}}, {{:required, [], [:logprob]}, {:number, [], []}}, {{:required, [], [:token]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}]
List of the most likely tokens and their log probability, at this token position. In rare cases, there may be fewer than the number of requestedtop_logprobsreturned.