View Source ExOpenAI.Components.ClickParam (ex_openai.ex v2.0.0-beta2)

A click action.

Fields

  • :button - required - ExOpenAI.Components.ClickButtonType.t()
    Indicates which mouse button was pressed during the click. One of left, right, wheel, back, or forward.

  • :keys - optional - [String.t()] | any()

  • :type - required - :click
    Specifies the event type. For a click action, this property is always click.
    Allowed values: "click"
    Default: "click"

  • :x - required - integer()
    The x-coordinate where the click occurred.

  • :y - required - integer()
    The y-coordinate where the click occurred.

Summary

Types

@type t() :: %ExOpenAI.Components.ClickParam{
  button: ExOpenAI.Components.ClickButtonType.t(),
  keys: ([String.t()] | any()) | nil,
  type: :click,
  x: integer(),
  y: integer()
}