View Source ExOpenAI.Components.ComparisonFilter (ex_openai.ex v2.0.0-beta2)

A filter used to compare a specified attribute key to a given value using a defined comparison operation.

Fields

  • :key - required - String.t()
    The key to compare against the value.

  • :type - required - :eq | :ne | :gt | :gte | :lt | :lte | :in | :nin
    Specifies the comparison operator: eq, ne, gt, gte, lt, lte, in, nin.

  • eq: equals
  • ne: not equal
  • gt: greater than
  • gte: greater than or equal
  • lt: less than
  • lte: less than or equal
  • in: in
  • nin: not in
    Allowed values: "eq", "ne", "gt", "gte", "lt", "lte", "in", "nin"
    Default: "eq"
  • :value - required - String.t() | number() | boolean() | [String.t() | number()]
    The value to compare against the attribute key; supports string, number, or boolean types.

Summary

Types

@type t() :: %ExOpenAI.Components.ComparisonFilter{
  key: String.t(),
  type: ((((((:eq | :ne) | :gt) | :gte) | :lt) | :lte) | :in) | :nin,
  value: ((String.t() | number()) | boolean()) | [String.t() | number()]
}