View Source ExOpenAI.Components.CreateEvalItem (ex_openai.ex v2.0.0-beta2)

A chat message that makes up the prompt or context. May include variable references to the item namespace, ie {{item.name}}.

Summary

Types