View Source ExOpenAI.Components.CreateEvalResponsesRunDataSource (ex_openai.ex v2.0.0-beta2)

A ResponsesRunDataSource object describing a model sampling configuration.

Fields

  • :input_messages - optional - {:%{}, [], [{{:required, [], [:template]}, {:list, [], [{:|, [], [{:%{}, [], [{{:required, [], [:content]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:required, [], [:role]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}, {{:., [], [ExOpenAI.Components.EvalItem, :t]}, [], []}]}]}}, {{:required, [], [:type]}, :template}]} | {:%{}, [], [{{:required, [], [:item_reference]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:required, [], [:type]}, :item_reference}]}
    Used when sampling from a model. Dictates the structure of the messages passed into the model. Can either be a reference to a prebuilt trajectory (ie, item.input_trajectory), or a template with variable references to the item namespace.

  • :model - optional - String.t()
    The name of the model to use for generating completions (e.g. "o3-mini").

  • :sampling_params - optional - {:%{}, [], [{{:optional, [], [:max_completion_tokens]}, {:integer, [], []}}, {{:optional, [], [:reasoning_effort]}, {{:., [], [ExOpenAI.Components.ReasoningEffort, :t]}, [], []}}, {{:optional, [], [:seed]}, {:integer, [], []}}, {{:optional, [], [:temperature]}, {:number, [], []}}, {{:optional, [], [:text]}, {:%{}, [], [{{:optional, [], [:format]}, {{:., [], [ExOpenAI.Components.TextResponseFormatConfiguration, :t]}, [], []}}]}}, {{:optional, [], [:tools]}, {:list, [], [{{:., [], [ExOpenAI.Components.Tool, :t]}, [], []}]}}, {{:optional, [], [:top_p]}, {:number, [], []}}]}

  • :source - required - ExOpenAI.Components.EvalJsonlFileContentSource.t() | ExOpenAI.Components.EvalJsonlFileIdSource.t() | ExOpenAI.Components.EvalResponsesSource.t()
    Determines what populates the item namespace in this run's data source.

  • :type - required - :responses
    The type of run data source. Always responses.
    Allowed values: "responses"
    Default: "responses"

Summary

Types

@type t() :: %ExOpenAI.Components.CreateEvalResponsesRunDataSource{
  input_messages:
    (%{
       template: [
         %{content: String.t(), role: String.t()}
         | ExOpenAI.Components.EvalItem.t()
       ],
       type: :template
     }
     | %{item_reference: String.t(), type: :item_reference})
    | nil,
  model: String.t() | nil,
  sampling_params:
    %{
      optional(:max_completion_tokens) => integer(),
      optional(:reasoning_effort) => ExOpenAI.Components.ReasoningEffort.t(),
      optional(:seed) => integer(),
      optional(:temperature) => number(),
      optional(:text) => %{
        optional(:format) =>
          ExOpenAI.Components.TextResponseFormatConfiguration.t()
      },
      optional(:tools) => [ExOpenAI.Components.Tool.t()],
      optional(:top_p) => number()
    }
    | nil,
  source:
    (ExOpenAI.Components.EvalJsonlFileContentSource.t()
     | ExOpenAI.Components.EvalJsonlFileIdSource.t())
    | ExOpenAI.Components.EvalResponsesSource.t(),
  type: :responses
}