View Source ExOpenAI.Components.CreateGroupUserBody (ex_openai.ex v2.0.0-beta2)

Request payload for adding a user to a group.

Fields

  • :user_id - required - String.t()
    Identifier of the user to add to the group.

Summary

Types

@type t() :: %ExOpenAI.Components.CreateGroupUserBody{user_id: String.t()}