View Source ExOpenAI.Components.CreateTranscriptionRequest (ex_openai.ex v2.0.0-beta2)

Module for representing the OpenAI schema CreateTranscriptionRequest.

Fields

  • :chunking_strategy - optional - :auto | ExOpenAI.Components.VadConfig.t() | any()

  • :file - required - binary()
    The audio file object (not file name) to transcribe, in one of these formats: flac, mp3, mp4, mpeg, mpga, m4a, ogg, wav, or webm.
    Format: binary

  • :include - optional - [ExOpenAI.Components.TranscriptionInclude.t()]
    Additional information to include in the transcription response. logprobs will return the log probabilities of the tokens in the response to understand the model's confidence in the transcription. logprobs only works with response_format set to json and only with the models gpt-4o-transcribe, gpt-4o-mini-transcribe, and gpt-4o-mini-transcribe-2025-12-15. This field is not supported when using gpt-4o-transcribe-diarize.

  • :known_speaker_names - optional - [String.t()]
    Optional list of speaker names that correspond to the audio samples provided in known_speaker_references[]. Each entry should be a short identifier (for example customer or agent). Up to 4 speakers are supported.
    Constraints: maxItems: 4

  • :known_speaker_references - optional - [String.t()]
    Optional list of audio samples (as data URLs) that contain known speaker references matching known_speaker_names[]. Each sample must be between 2 and 10 seconds, and can use any of the same input audio formats supported by file.
    Constraints: maxItems: 4

  • :language - optional - String.t()
    The language of the input audio. Supplying the input language in ISO-639-1 (e.g. en) format will improve accuracy and latency.

  • :model - required - String.t() | :"whisper-1" | :"gpt-4o-transcribe" | :"gpt-4o-mini-transcribe" | :"gpt-4o-mini-transcribe-2025-12-15" | :"gpt-4o-transcribe-diarize"
    ID of the model to use. The options are gpt-4o-transcribe, gpt-4o-mini-transcribe, gpt-4o-mini-transcribe-2025-12-15, whisper-1 (which is powered by our open source Whisper V2 model), and gpt-4o-transcribe-diarize.

  • :prompt - optional - String.t()
    An optional text to guide the model's style or continue a previous audio segment. The prompt should match the audio language. This field is not supported when using gpt-4o-transcribe-diarize.

  • :response_format - optional - ExOpenAI.Components.AudioResponseFormat.t()

  • :stream - optional - boolean() | any()

  • :temperature - optional - number()
    The sampling temperature, between 0 and 1. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. If set to 0, the model will use log probability to automatically increase the temperature until certain thresholds are hit.
    Default: 0

  • :timestamp_granularities - optional - [:word | :segment]
    The timestamp granularities to populate for this transcription. response_format must be set verbose_json to use timestamp granularities. Either or both of these options are supported: word, or segment. Note: There is no additional latency for segment timestamps, but generating word timestamps incurs additional latency. This option is not available for gpt-4o-transcribe-diarize.
    Default: ["segment"]

Summary

Types

@type t() :: %ExOpenAI.Components.CreateTranscriptionRequest{
  chunking_strategy:
    ((:auto | ExOpenAI.Components.VadConfig.t()) | any()) | nil,
  file: binary(),
  include: [ExOpenAI.Components.TranscriptionInclude.t()] | nil,
  known_speaker_names: [String.t()] | nil,
  known_speaker_references: [String.t()] | nil,
  language: String.t() | nil,
  model:
    String.t()
    | (((:"whisper-1" | :"gpt-4o-transcribe") | :"gpt-4o-mini-transcribe")
       | :"gpt-4o-mini-transcribe-2025-12-15")
    | :"gpt-4o-transcribe-diarize",
  prompt: String.t() | nil,
  response_format: ExOpenAI.Components.AudioResponseFormat.t() | nil,
  stream: (boolean() | any()) | nil,
  temperature: number() | nil,
  timestamp_granularities: [:word | :segment] | nil
}