View Source ExOpenAI.Components.CreateTranscriptionResponseJson (ex_openai.ex v2.0.0-beta2)

Represents a transcription response returned by model, based on the provided input.

Fields

  • :logprobs - optional - [{:%{}, [], [{{:optional, [], [:bytes]}, {:list, [], [{:number, [], []}]}}, {{:optional, [], [:logprob]}, {:number, [], []}}, {{:optional, [], [:token]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}]
    The log probabilities of the tokens in the transcription. Only returned with the models gpt-4o-transcribe and gpt-4o-mini-transcribe if logprobs is added to the include array.

  • :text - required - String.t()
    The transcribed text.

  • :usage - optional - map()
    Token usage statistics for the request.

Summary

Types

@type t() :: %ExOpenAI.Components.CreateTranscriptionResponseJson{
  logprobs:
    [
      %{
        optional(:bytes) => [number()],
        optional(:logprob) => number(),
        optional(:token) => String.t()
      }
    ]
    | nil,
  text: String.t(),
  usage: map() | nil
}