View Source ExOpenAI.Components.CustomToolCall (ex_openai.ex v2.0.0-beta2)

A call to a custom tool created by the model.

Fields

  • :call_id - required - String.t()
    An identifier used to map this custom tool call to a tool call output.

  • :id - optional - String.t()
    The unique ID of the custom tool call in the OpenAI platform.

  • :input - required - String.t()
    The input for the custom tool call generated by the model.

  • :name - required - String.t()
    The name of the custom tool being called.

  • :namespace - optional - String.t()
    The namespace of the custom tool being called.

  • :type - required - :custom_tool_call
    The type of the custom tool call. Always custom_tool_call.
    Allowed values: "custom_tool_call"

Summary

Types

@type t() :: %ExOpenAI.Components.CustomToolCall{
  call_id: String.t(),
  id: String.t() | nil,
  input: String.t(),
  name: String.t(),
  namespace: String.t() | nil,
  type: :custom_tool_call
}