View Source ExOpenAI.Components.CustomToolCallOutputResource (ex_openai.ex v2.0.0-beta2)

Module for representing the OpenAI schema CustomToolCallOutputResource.

Fields

  • :call_id - required - String.t()
    The call ID, used to map this custom tool call output to a custom tool call.

  • :created_by - optional - String.t()
    The identifier of the actor that created the item.

  • :id - required - String.t()
    The unique ID of the custom tool call output item.

  • :output - required - String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()]
    The output from the custom tool call generated by your code. Can be a string or an list of output content.

  • :status - required - ExOpenAI.Components.FunctionCallOutputStatusEnum.t()
    The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.

  • :type - required - :custom_tool_call_output
    The type of the custom tool call output. Always custom_tool_call_output.
    Allowed values: "custom_tool_call_output"

Summary

Types

@type t() :: %ExOpenAI.Components.CustomToolCallOutputResource{
  call_id: String.t(),
  created_by: String.t() | nil,
  id: String.t(),
  output:
    String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()],
  status: ExOpenAI.Components.FunctionCallOutputStatusEnum.t(),
  type: :custom_tool_call_output
}