View Source ExOpenAI.Components.EvalApiError (ex_openai.ex v2.0.0-beta2)
An object representing an error response from the Eval API.
Fields
:code- required -String.t()
The error code.:message- required -String.t()
The error message.
An object representing an error response from the Eval API.
:code - required - String.t()
The error code.
:message - required - String.t()
The error message.