View Source ExOpenAI.Components.EvalCustomDataSourceConfig (ex_openai.ex v2.0.0-beta2)

A CustomDataSourceConfig which specifies the schema of your item and optionally sample namespaces. The response schema defines the shape of the data that will be:

  • Used to define your testing criteria and
  • What data is required when creating a run

Fields

  • :schema - required - map()
    The json schema for the run data source items. Learn how to build JSON schemas here.

  • :type - required - :custom
    The type of data source. Always custom.
    Allowed values: "custom"
    Default: "custom"

Summary

Types

@type t() :: %ExOpenAI.Components.EvalCustomDataSourceConfig{
  schema: map(),
  type: :custom
}