View Source ExOpenAI.Components.EvalItemContent (ex_openai.ex v2.0.0-beta)

Inputs to the model - can contain template strings. Supports text, output text, input images, and input audio, either as a single item or an array of items.

Type

any() | any()

Summary

Types