View Source ExOpenAI.Components.EvalItemContentArray (ex_openai.ex v2.0.0-beta)

A list of inputs, each of which may be either an input text, output text, input image, or input audio object.

Type

[any()]

Summary

Types