View Source ExOpenAI.Components.EvalRunList (ex_openai.ex v2.0.0-beta2)
An object representing a list of runs for an evaluation.
Fields
:data- required -[ExOpenAI.Components.EvalRun.t()]
An array of eval run objects.:first_id- required -String.t()
The identifier of the first eval run in the data array.:has_more- required -boolean()
Indicates whether there are more evals available.:last_id- required -String.t()
The identifier of the last eval run in the data array.:object- required -:list
The type of this object. It is always set to "list".
Allowed values:"list"
Default:"list"
Summary
Types
@type t() :: %ExOpenAI.Components.EvalRunList{ data: [ExOpenAI.Components.EvalRun.t()], first_id: String.t(), has_more: boolean(), last_id: String.t(), object: :list }