View Source ExOpenAI.Components.EvalRunOutputItemResult (ex_openai.ex v2.0.0-beta2)

A single grader result for an evaluation run output item.

Fields

  • :name - required - String.t()
    The name of the grader.

  • :passed - required - boolean()
    Whether the grader considered the output a pass.

  • :sample - optional - map() | any()
    Optional sample or intermediate data produced by the grader.

  • :score - required - number()
    The numeric score produced by the grader.

  • :type - optional - String.t()
    The grader type (for example, "string-check-grader").

Summary

Types

@type t() :: %ExOpenAI.Components.EvalRunOutputItemResult{
  name: String.t(),
  passed: boolean(),
  sample: (map() | any()) | nil,
  score: number(),
  type: String.t() | nil
}