View Source ExOpenAI.Components.ExpiresAfterParam (ex_openai.ex v2.0.0-beta2)

Controls when the session expires relative to an anchor timestamp.

Fields

  • :anchor - required - :created_at
    Base timestamp used to calculate expiration. Currently fixed to created_at.
    Allowed values: "created_at"
    Default: "created_at"

  • :seconds - required - integer()
    Number of seconds after the anchor when the session expires.
    Constraints: minimum: 1, maximum: 600

Summary

Types

@type t() :: %ExOpenAI.Components.ExpiresAfterParam{
  anchor: :created_at,
  seconds: integer()
}