View Source ExOpenAI.Components.FunctionCallOutputItemParam (ex_openai.ex v2.0.0-beta2)

The output of a function tool call.

Fields

  • :call_id - required - String.t()
    The unique ID of the function tool call generated by the model.
    Constraints: minLength: 1, maxLength: 64

  • :id - optional - String.t() | any()

  • :output - required - String.t() | [ExOpenAI.Components.InputTextContentParam.t() | ExOpenAI.Components.InputImageContentParamAutoParam.t() | ExOpenAI.Components.InputFileContentParam.t()]
    Text, image, or file output of the function tool call.

  • :status - optional - ExOpenAI.Components.FunctionCallItemStatus.t() | any()

  • :type - required - :function_call_output
    The type of the function tool call output. Always function_call_output.
    Allowed values: "function_call_output"
    Default: "function_call_output"

Summary

Types

@type t() :: %ExOpenAI.Components.FunctionCallOutputItemParam{
  call_id: String.t(),
  id: (String.t() | any()) | nil,
  output:
    String.t()
    | [
        (ExOpenAI.Components.InputTextContentParam.t()
         | ExOpenAI.Components.InputImageContentParamAutoParam.t())
        | ExOpenAI.Components.InputFileContentParam.t()
      ],
  status: (ExOpenAI.Components.FunctionCallItemStatus.t() | any()) | nil,
  type: :function_call_output
}