View Source ExOpenAI.Components.FunctionObject (ex_openai.ex v2.0.0-beta2)

Module for representing the OpenAI schema FunctionObject.

Fields

  • :description - optional - String.t()
    A description of what the function does, used by the model to choose when and how to call the function.

  • :name - required - String.t()
    The name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.

  • :parameters - optional - ExOpenAI.Components.FunctionParameters.t()

  • :strict - optional - boolean() | any()

Summary

Types

@type t() :: %ExOpenAI.Components.FunctionObject{
  description: String.t() | nil,
  name: String.t(),
  parameters: ExOpenAI.Components.FunctionParameters.t() | nil,
  strict: (boolean() | any()) | nil
}