View Source ExOpenAI.Components.FunctionParameters (ex_openai.ex v2.0.0-beta2)

The parameters the functions accepts, described as a JSON Schema object. See the guide for examples, and the JSON Schema reference for documentation about the format.

Omitting parameters defines a function with an empty parameter list.

Summary

Types