View Source ExOpenAI.Components.FunctionShellActionParam (ex_openai.ex v2.0.0-beta2)

Commands and limits describing how to run the shell tool call.

Fields

  • :commands - required - [String.t()]
    Ordered shell commands for the execution environment to run.

  • :max_output_length - optional - integer() | any()

  • :timeout_ms - optional - integer() | any()

Summary

Types

@type t() :: %ExOpenAI.Components.FunctionShellActionParam{
  commands: [String.t()],
  max_output_length: (integer() | any()) | nil,
  timeout_ms: (integer() | any()) | nil
}