View Source ExOpenAI.Components.FunctionShellCall (ex_openai.ex v2.0.0-beta2)

A tool call that executes one or more shell commands in a managed environment.

Fields

  • :action - required - ExOpenAI.Components.FunctionShellAction.t()
    The shell commands and limits that describe how to run the tool call.

  • :call_id - required - String.t()
    The unique ID of the shell tool call generated by the model.

  • :created_by - optional - String.t()
    The ID of the entity that created this tool call.

  • :environment - required - ExOpenAI.Components.LocalEnvironmentResource.t() | ExOpenAI.Components.ContainerReferenceResource.t() | any()

  • :id - required - String.t()
    The unique ID of the shell tool call. Populated when this item is returned via API.

  • :status - required - ExOpenAI.Components.LocalShellCallStatus.t()
    The status of the shell call. One of in_progress, completed, or incomplete.

  • :type - required - :shell_call
    The type of the item. Always shell_call.
    Allowed values: "shell_call"
    Default: "shell_call"

Summary

Types

@type t() :: %ExOpenAI.Components.FunctionShellCall{
  action: ExOpenAI.Components.FunctionShellAction.t(),
  call_id: String.t(),
  created_by: String.t() | nil,
  environment:
    (ExOpenAI.Components.LocalEnvironmentResource.t()
     | ExOpenAI.Components.ContainerReferenceResource.t())
    | any(),
  id: String.t(),
  status: ExOpenAI.Components.LocalShellCallStatus.t(),
  type: :shell_call
}