View Source ExOpenAI.Components.FunctionShellCallOutputItemParam (ex_openai.ex v2.0.0-beta2)

The streamed output items emitted by a shell tool call.

Fields

  • :call_id - required - String.t()
    The unique ID of the shell tool call generated by the model.
    Constraints: minLength: 1, maxLength: 64

  • :id - optional - String.t() | any()

  • :max_output_length - optional - integer() | any()

  • :output - required - [ExOpenAI.Components.FunctionShellCallOutputContentParam.t()]
    Captured chunks of stdout and stderr output, along with their associated outcomes.

  • :status - optional - ExOpenAI.Components.FunctionShellCallItemStatus.t() | any()

  • :type - required - :shell_call_output
    The type of the item. Always shell_call_output.
    Allowed values: "shell_call_output"
    Default: "shell_call_output"

Summary

Types

@type t() :: %ExOpenAI.Components.FunctionShellCallOutputItemParam{
  call_id: String.t(),
  id: (String.t() | any()) | nil,
  max_output_length: (integer() | any()) | nil,
  output: [ExOpenAI.Components.FunctionShellCallOutputContentParam.t()],
  status: (ExOpenAI.Components.FunctionShellCallItemStatus.t() | any()) | nil,
  type: :shell_call_output
}