View Source ExOpenAI.Components.FunctionToolCall (ex_openai.ex v2.0.0-beta2)

A tool call to run a function. See the function calling guide for more information.

Fields

  • :arguments - required - String.t()
    A JSON string of the arguments to pass to the function.

  • :call_id - required - String.t()
    The unique ID of the function tool call generated by the model.

  • :id - optional - String.t()
    The unique ID of the function tool call.

  • :name - required - String.t()
    The name of the function to run.

  • :namespace - optional - String.t()
    The namespace of the function to run.

  • :status - optional - :in_progress | :completed | :incomplete
    The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.
    Allowed values: "in_progress", "completed", "incomplete"

  • :type - required - :function_call
    The type of the function tool call. Always function_call.
    Allowed values: "function_call"

Summary

Types

@type t() :: %ExOpenAI.Components.FunctionToolCall{
  arguments: String.t(),
  call_id: String.t(),
  id: String.t() | nil,
  name: String.t(),
  namespace: String.t() | nil,
  status: ((:in_progress | :completed) | :incomplete) | nil,
  type: :function_call
}