View Source ExOpenAI.Components.GraderPython (ex_openai.ex v2.0.0-beta2)

A PythonGrader object that runs a python script on the input.

Fields

  • :image_tag - optional - String.t()
    The image tag to use for the python script.

  • :name - required - String.t()
    The name of the grader.

  • :source - required - String.t()
    The source code of the python script.

  • :type - required - :python
    The object type, which is always python.
    Allowed values: "python"

Summary

Types

@type t() :: %ExOpenAI.Components.GraderPython{
  image_tag: String.t() | nil,
  name: String.t(),
  source: String.t(),
  type: :python
}