View Source ExOpenAI.Components.ImageGenInputUsageDetails (ex_openai.ex v2.0.0-beta2)
The input tokens detailed information for the image generation.
Fields
:image_tokens- required -integer()
The number of image tokens in the input prompt.:text_tokens- required -integer()
The number of text tokens in the input prompt.