View Source ExOpenAI.Components.ImageGenOutputTokensDetails (ex_openai.ex v2.0.0-beta2)
The output token details for the image generation.
Fields
:image_tokens- required -integer()
The number of image output tokens generated by the model.:text_tokens- required -integer()
The number of text output tokens generated by the model.