View Source ExOpenAI.Components.ImageGenUsage (ex_openai.ex v2.0.0-beta2)

For gpt-image-1 only, the token usage information for the image generation.

Fields

  • :input_tokens - required - integer()
    The number of tokens (images and text) in the input prompt.

  • :input_tokens_details - required - ExOpenAI.Components.ImageGenInputUsageDetails.t()

  • :output_tokens - required - integer()
    The number of output tokens generated by the model.

  • :output_tokens_details - optional - ExOpenAI.Components.ImageGenOutputTokensDetails.t()

  • :total_tokens - required - integer()
    The total number of tokens (images and text) used for the image generation.

Summary

Types

@type t() :: %ExOpenAI.Components.ImageGenUsage{
  input_tokens: integer(),
  input_tokens_details: ExOpenAI.Components.ImageGenInputUsageDetails.t(),
  output_tokens: integer(),
  output_tokens_details:
    ExOpenAI.Components.ImageGenOutputTokensDetails.t() | nil,
  total_tokens: integer()
}