View Source ExOpenAI.Components.ImagesUsage (ex_openai.ex v2.0.0-beta2)
For the GPT image models only, the token usage information for the image generation.
Fields
:input_tokens- required -integer()
The number of tokens (images and text) in the input prompt.:input_tokens_details- required -{:%{}, [], [{{:required, [], [:image_tokens]}, {:integer, [], []}}, {{:required, [], [:text_tokens]}, {:integer, [], []}}]}
The input tokens detailed information for the image generation.:output_tokens- required -integer()
The number of image tokens in the output image.:total_tokens- required -integer()
The total number of tokens (images and text) used for the image generation.