View Source ExOpenAI.Components.InputMessageContentList (ex_openai.ex v2.0.0-beta)
A list of one or many input items to the model, containing different content types.
Type
[any()]
Summary
Types
@type t() :: [ExOpenAI.Components.InputContent.t()]
A list of one or many input items to the model, containing different content types.
[any()]
@type t() :: [ExOpenAI.Components.InputContent.t()]