View Source ExOpenAI.Components.InviteRequest (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema InviteRequest.
Fields
:email- required -String.t()
Send an email to this address:projects- optional -[{:%{}, [], [{{:required, [], [:id]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:required, [], [:role]}, {:|, [], [:member, :owner]}}]}]
An array of projects to which membership is granted at the same time the org invite is accepted. If omitted, the user will be invited to the default project for compatibility with legacy behavior.:role- required -:reader | :ownerownerorreader
Allowed values:"reader","owner"