View Source ExOpenAI.Components.KeyPressAction (ex_openai.ex v2.0.0-beta2)

A collection of keypresses the model would like to perform.

Fields

  • :keys - required - [String.t()]
    The combination of keys the model is requesting to be pressed. This is an array of strings, each representing a key.

  • :type - required - :keypress
    Specifies the event type. For a keypress action, this property is always set to keypress.
    Allowed values: "keypress"
    Default: "keypress"

Summary

Types

@type t() :: %ExOpenAI.Components.KeyPressAction{keys: [String.t()], type: :keypress}