View Source ExOpenAI.Components.LocalShellToolCall (ex_openai.ex v2.0.0-beta2)

A tool call to run a command on the local shell.

Fields

  • :action - required - ExOpenAI.Components.LocalShellExecAction.t()

  • :call_id - required - String.t()
    The unique ID of the local shell tool call generated by the model.

  • :id - required - String.t()
    The unique ID of the local shell call.

  • :status - required - :in_progress | :completed | :incomplete
    The status of the local shell call.
    Allowed values: "in_progress", "completed", "incomplete"

  • :type - required - :local_shell_call
    The type of the local shell call. Always local_shell_call.
    Allowed values: "local_shell_call"

Summary

Types

@type t() :: %ExOpenAI.Components.LocalShellToolCall{
  action: ExOpenAI.Components.LocalShellExecAction.t(),
  call_id: String.t(),
  id: String.t(),
  status: (:in_progress | :completed) | :incomplete,
  type: :local_shell_call
}