View Source ExOpenAI.Components.MCPToolFilter (ex_openai.ex v2.0.0-beta2)

A filter object to specify which tools are allowed.

Fields

  • :read_only - optional - boolean()
    Indicates whether or not a tool modifies data or is read-only. If an MCP server is annotated with readOnlyHint, it will match this filter.

  • :tool_names - optional - [String.t()]
    List of allowed tool names.

Summary

Types

@type t() :: %ExOpenAI.Components.MCPToolFilter{
  read_only: boolean() | nil,
  tool_names: [String.t()] | nil
}