View Source ExOpenAI.Components.MessageDeltaContentImageFileObject (ex_openai.ex v2.0.0-beta2)
References an image File in the content of a message.
Fields
:image_file- optional -{:%{}, [], [{{:optional, [], [:detail]}, {:|, [], [{:|, [], [:auto, :low]}, :high]}}, {{:optional, [], [:file_id]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}:index- required -integer()
The index of the content part in the message.:type- required -:image_file
Alwaysimage_file.
Allowed values:"image_file"