View Source ExOpenAI.Components.MessageDeltaContentRefusalObject (ex_openai.ex v2.0.0-beta2)
The refusal content that is part of a message.
Fields
:index- required -integer()
The index of the refusal part in the message.:refusal- optional -String.t():type- required -:refusal
Alwaysrefusal.
Allowed values:"refusal"