View Source ExOpenAI.Components.MessageDeltaContentTextAnnotationsFileCitationObject (ex_openai.ex v2.0.0-beta2)

A citation within the message that points to a specific quote from a specific File associated with the assistant or the message. Generated when the assistant uses the "file_search" tool to search files.

Fields

  • :end_index - optional - integer()
    Constraints: minimum: 0

  • :file_citation - optional - {:%{}, [], [{{:optional, [], [:file_id]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:optional, [], [:quote]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}

  • :index - required - integer()
    The index of the annotation in the text content part.

  • :start_index - optional - integer()
    Constraints: minimum: 0

  • :text - optional - String.t()
    The text in the message content that needs to be replaced.

  • :type - required - :file_citation
    Always file_citation.
    Allowed values: "file_citation"

Summary

Types

@type t() ::
  %ExOpenAI.Components.MessageDeltaContentTextAnnotationsFileCitationObject{
    end_index: integer() | nil,
    file_citation:
      %{optional(:file_id) => String.t(), optional(:quote) => String.t()} | nil,
    index: integer(),
    start_index: integer() | nil,
    text: String.t() | nil,
    type: :file_citation
  }