View Source ExOpenAI.Components.ModelIdsCompaction (ex_openai.ex v2.0.0-beta2)

Model ID used to generate the response, like gpt-5 or o3. OpenAI offers a wide range of models with different capabilities, performance characteristics, and price points. Refer to the model guide to browse and compare available models.

Type

ExOpenAI.Components.ModelIdsResponses.t() | String.t() | any()

Summary

Types