View Source ExOpenAI.Components.OtherChunkingStrategyResponseParam (ex_openai.ex v2.0.0-beta2)

This is returned when the chunking strategy is unknown. Typically, this is because the file was indexed before the chunking_strategy concept was introduced in the API.

Fields

  • :type - required - :other
    Always other.
    Allowed values: "other"

Summary

Types

@type t() :: %ExOpenAI.Components.OtherChunkingStrategyResponseParam{type: :other}