View Source ExOpenAI.Components.ParallelToolCalls (ex_openai.ex v2.0.0-beta2)
Whether to enable parallel function calling during tool use.
Type
boolean()
Summary
Types
@type t() :: boolean()
Whether to enable parallel function calling during tool use.
boolean()
@type t() :: boolean()