View Source ExOpenAI.Components.PredictionContent (ex_openai.ex v2.0.0-beta2)

Static predicted output content, such as the content of a text file that is being regenerated.

Fields

  • :content - required - String.t() | [ExOpenAI.Components.ChatCompletionRequestMessageContentPartText.t()]
    The content that should be matched when generating a model response. If generated tokens would match this content, the entire model response can be returned much more quickly.

  • :type - required - :content
    The type of the predicted content you want to provide. This type is currently always content.
    Allowed values: "content"

Summary

Types

@type t() :: %ExOpenAI.Components.PredictionContent{
  content:
    String.t()
    | [ExOpenAI.Components.ChatCompletionRequestMessageContentPartText.t()],
  type: :content
}