View Source ExOpenAI.Components.ProjectGroupListResource (ex_openai.ex v2.0.0-beta2)
Paginated list of groups that have access to a project.
Fields
:data- required -[ExOpenAI.Components.ProjectGroup.t()]
Project group memberships returned in the current page.:has_more- required -boolean()
Whether additional project group memberships are available.:next- required -String.t() | any()
Cursor to fetch the next page of results, ornullwhen there are no more results.:object- required -:list
Alwayslist.
Allowed values:"list"
Summary
Types
@type t() :: %ExOpenAI.Components.ProjectGroupListResource{ data: [ExOpenAI.Components.ProjectGroup.t()], has_more: boolean(), next: String.t() | any(), object: :list }