View Source ExOpenAI.Components.PublicRoleListResource (ex_openai.ex v2.0.0-beta2)
Paginated list of roles available on an organization or project.
Fields
:data- required -[ExOpenAI.Components.Role.t()]
Roles returned in the current page.:has_more- required -boolean()
Whether more roles are available when paginating.:next- required -String.t() | any()
Cursor to fetch the next page of results, ornullwhen there are no additional roles.:object- required -:list
Alwayslist.
Allowed values:"list"
Summary
Types
@type t() :: %ExOpenAI.Components.PublicRoleListResource{ data: [ExOpenAI.Components.Role.t()], has_more: boolean(), next: String.t() | any(), object: :list }