View Source ExOpenAI.Components.RealtimeBetaClientEventConversationItemRetrieve (ex_openai.ex v2.0.0-beta2)

Send this event when you want to retrieve the server's representation of a specific item in the conversation history. This is useful, for example, to inspect user audio after noise cancellation and VAD. The server will respond with a conversation.item.retrieved event, unless the item does not exist in the conversation history, in which case the server will respond with an error.

Fields

  • :event_id - optional - String.t()
    Optional client-generated ID used to identify this event.

  • :item_id - required - String.t()
    The ID of the item to retrieve.

  • :type - required - :"conversation.item.retrieve"
    The event type, must be conversation.item.retrieve.
    Allowed values: "conversation.item.retrieve"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeBetaClientEventConversationItemRetrieve{
  event_id: String.t() | nil,
  item_id: String.t(),
  type: :"conversation.item.retrieve"
}