View Source ExOpenAI.Components.RealtimeBetaServerEventResponseDone (ex_openai.ex v2.0.0-beta2)

Returned when a Response is done streaming. Always emitted, no matter the final state. The Response object included in the response.done event will include all output Items in the Response but will omit the raw audio data.

Fields

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :response - required - ExOpenAI.Components.RealtimeBetaResponse.t()

  • :type - required - :"response.done"
    The event type, must be response.done.
    Allowed values: "response.done"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeBetaServerEventResponseDone{
  event_id: String.t(),
  response: ExOpenAI.Components.RealtimeBetaResponse.t(),
  type: :"response.done"
}