View Source ExOpenAI.Components.RealtimeBetaServerEventResponseTextDelta (ex_openai.ex v2.0.0-beta2)
Returned when the text value of an "output_text" content part is updated.
Fields
:content_index- required -integer()
The index of the content part in the item's content array.:delta- required -String.t()
The text delta.:event_id- required -String.t()
The unique ID of the server event.:item_id- required -String.t()
The ID of the item.:output_index- required -integer()
The index of the output item in the response.:response_id- required -String.t()
The ID of the response.:type- required -:"response.output_text.delta"
The event type, must beresponse.output_text.delta.
Allowed values:"response.output_text.delta"