View Source ExOpenAI.Components.RealtimeClientEventOutputAudioBufferClear (ex_openai.ex v2.0.0-beta2)

WebRTC/SIP Only: Emit to cut off the current audio response. This will trigger the server to stop generating audio and emit a output_audio_buffer.cleared event. This event should be preceded by a response.cancel client event to stop the generation of the current response. Learn more.

Fields

  • :event_id - optional - String.t()
    The unique ID of the client event used for error handling.

  • :type - required - :"output_audio_buffer.clear"
    The event type, must be output_audio_buffer.clear.
    Allowed values: "output_audio_buffer.clear"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeClientEventOutputAudioBufferClear{
  event_id: String.t() | nil,
  type: :"output_audio_buffer.clear"
}