View Source ExOpenAI.Components.RealtimeClientEventResponseCancel (ex_openai.ex v2.0.0-beta2)
Send this event to cancel an in-progress response. The server will respond
with a response.done event with a status of response.status=cancelled. If
there is no response to cancel, the server will respond with an error. It's safe
to call response.cancel even if no response is in progress, an error will be
returned the session will remain unaffected.
Fields
:event_id- optional -String.t()
Optional client-generated ID used to identify this event.
Constraints: maxLength: 512:response_id- optional -String.t()
A specific response ID to cancel - if not provided, will cancel an in-progress response in the default conversation.:type- required -:"response.cancel"
The event type, must beresponse.cancel.
Allowed values:"response.cancel"