View Source ExOpenAI.Components.RealtimeConversationItemFunctionCallOutput (ex_openai.ex v2.0.0-beta2)

A function call output item in a Realtime conversation.

Fields

  • :call_id - required - String.t()
    The ID of the function call this output is for.

  • :id - optional - String.t()
    The unique ID of the item. This may be provided by the client or generated by the server.

  • :object - optional - :"realtime.item"
    Identifier for the API object being returned - always realtime.item. Optional when creating a new item.
    Allowed values: "realtime.item"

  • :output - required - String.t()
    The output of the function call, this is free text and can contain any information or simply be empty.

  • :status - optional - :completed | :incomplete | :in_progress
    The status of the item. Has no effect on the conversation.
    Allowed values: "completed", "incomplete", "in_progress"

  • :type - required - :function_call_output
    The type of the item. Always function_call_output.
    Allowed values: "function_call_output"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeConversationItemFunctionCallOutput{
  call_id: String.t(),
  id: String.t() | nil,
  object: :"realtime.item" | nil,
  output: String.t(),
  status: ((:completed | :incomplete) | :in_progress) | nil,
  type: :function_call_output
}