View Source ExOpenAI.Components.RealtimeConversationItemMessageSystem (ex_openai.ex v2.0.0-beta2)
A system message in a Realtime conversation can be used to provide additional context or instructions to the model. This is similar but distinct from the instruction prompt provided at the start of a conversation, as system messages can be added at any point in the conversation. For major changes to the conversation's behavior, use instructions, but for smaller updates (e.g. "the user is now asking about a different topic"), use system messages.
Fields
:content- required -[{:%{}, [], [{{:optional, [], [:text]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:optional, [], [:type]}, :input_text}]}]
The content of the message.:id- optional -String.t()
The unique ID of the item. This may be provided by the client or generated by the server.:object- optional -:"realtime.item"
Identifier for the API object being returned - alwaysrealtime.item. Optional when creating a new item.
Allowed values:"realtime.item":role- required -:system
The role of the message sender. Alwayssystem.
Allowed values:"system":status- optional -:completed | :incomplete | :in_progress
The status of the item. Has no effect on the conversation.
Allowed values:"completed","incomplete","in_progress":type- required -:message
The type of the item. Alwaysmessage.
Allowed values:"message"