View Source ExOpenAI.Components.RealtimeCreateClientSecretRequest (ex_openai.ex v2.0.0-beta2)

Create a session and client secret for the Realtime API. The request can specify either a realtime or a transcription session configuration. Learn more about the Realtime API.

Fields

  • :expires_after - optional - {:%{}, [], [{{:optional, [], [:anchor]}, :created_at}, {{:optional, [], [:seconds]}, {:integer, [], []}}]}
    Configuration for the client secret expiration. Expiration refers to the time after which a client secret will no longer be valid for creating sessions. The session itself may continue after that time once started. A secret can be used to create multiple sessions until it expires.

  • :session - optional - ExOpenAI.Components.RealtimeSessionCreateRequestGA.t() | ExOpenAI.Components.RealtimeTranscriptionSessionCreateRequestGA.t()
    Session configuration to use for the client secret. Choose either a realtime session or a transcription session.

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeCreateClientSecretRequest{
  expires_after:
    %{optional(:anchor) => :created_at, optional(:seconds) => integer()} | nil,
  session:
    (ExOpenAI.Components.RealtimeSessionCreateRequestGA.t()
     | ExOpenAI.Components.RealtimeTranscriptionSessionCreateRequestGA.t())
    | nil
}