View Source ExOpenAI.Components.RealtimeCreateClientSecretResponse (ex_openai.ex v2.0.0-beta2)

Response from creating a session and client secret for the Realtime API.

Fields

  • :expires_at - required - integer()
    Expiration timestamp for the client secret, in seconds since epoch.

  • :session - required - ExOpenAI.Components.RealtimeSessionCreateResponseGA.t() | ExOpenAI.Components.RealtimeTranscriptionSessionCreateResponseGA.t()
    The session configuration for either a realtime or transcription session.

  • :value - required - String.t()
    The generated client secret value.

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeCreateClientSecretResponse{
  expires_at: integer(),
  session:
    ExOpenAI.Components.RealtimeSessionCreateResponseGA.t()
    | ExOpenAI.Components.RealtimeTranscriptionSessionCreateResponseGA.t(),
  value: String.t()
}