View Source ExOpenAI.Components.RealtimeServerEventConversationItemCreated (ex_openai.ex v2.0.0-beta2)
Returned when a conversation item is created. There are several scenarios that produce this event:
- The server is generating a Response, which if successful will produce
either one or two Items, which will be of type
message(roleassistant) or typefunction_call. - The input audio buffer has been committed, either by the client or the
server (in
server_vadmode). The server will take the content of the input audio buffer and add it to a new user message Item. - The client has sent a
conversation.item.createevent to add a new Item to the Conversation.
Fields
:event_id- required -String.t()
The unique ID of the server event.:item- required -ExOpenAI.Components.RealtimeConversationItem.t():previous_item_id- optional -String.t() | any():type- required -:"conversation.item.created"
The event type, must beconversation.item.created.
Allowed values:"conversation.item.created"
Summary
Types
@type t() :: %ExOpenAI.Components.RealtimeServerEventConversationItemCreated{ event_id: String.t(), item: ExOpenAI.Components.RealtimeConversationItem.t(), previous_item_id: (String.t() | any()) | nil, type: :"conversation.item.created" }