View Source ExOpenAI.Components.RealtimeServerEventConversationItemDeleted (ex_openai.ex v2.0.0-beta2)

Returned when an item in the conversation is deleted by the client with a conversation.item.delete event. This event is used to synchronize the server's understanding of the conversation history with the client's view.

Fields

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :item_id - required - String.t()
    The ID of the item that was deleted.

  • :type - required - :"conversation.item.deleted"
    The event type, must be conversation.item.deleted.
    Allowed values: "conversation.item.deleted"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeServerEventConversationItemDeleted{
  event_id: String.t(),
  item_id: String.t(),
  type: :"conversation.item.deleted"
}