View Source ExOpenAI.Components.RealtimeServerEventConversationItemRetrieved (ex_openai.ex v2.0.0-beta2)

Returned when a conversation item is retrieved with conversation.item.retrieve. This is provided as a way to fetch the server's representation of an item, for example to get access to the post-processed audio data after noise cancellation and VAD. It includes the full content of the Item, including audio data.

Fields

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :item - required - ExOpenAI.Components.RealtimeConversationItem.t()

  • :type - required - :"conversation.item.retrieved"
    The event type, must be conversation.item.retrieved.
    Allowed values: "conversation.item.retrieved"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeServerEventConversationItemRetrieved{
  event_id: String.t(),
  item: ExOpenAI.Components.RealtimeConversationItem.t(),
  type: :"conversation.item.retrieved"
}