View Source ExOpenAI.Components.RealtimeServerEventOutputAudioBufferStarted (ex_openai.ex v2.0.0-beta2)

WebRTC/SIP Only: Emitted when the server begins streaming audio to the client. This event is emitted after an audio content part has been added (response.content_part.added) to the response. Learn more.

Fields

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :response_id - required - String.t()
    The unique ID of the response that produced the audio.

  • :type - required - :"output_audio_buffer.started"
    The event type, must be output_audio_buffer.started.
    Allowed values: "output_audio_buffer.started"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeServerEventOutputAudioBufferStarted{
  event_id: String.t(),
  response_id: String.t(),
  type: :"output_audio_buffer.started"
}