View Source ExOpenAI.Components.RealtimeServerEventOutputAudioBufferStopped (ex_openai.ex v2.0.0-beta2)

WebRTC/SIP Only: Emitted when the output audio buffer has been completely drained on the server, and no more audio is forthcoming. This event is emitted after the full response data has been sent to the client (response.done). Learn more.

Fields

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :response_id - required - String.t()
    The unique ID of the response that produced the audio.

  • :type - required - :"output_audio_buffer.stopped"
    The event type, must be output_audio_buffer.stopped.
    Allowed values: "output_audio_buffer.stopped"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeServerEventOutputAudioBufferStopped{
  event_id: String.t(),
  response_id: String.t(),
  type: :"output_audio_buffer.stopped"
}