View Source ExOpenAI.Components.RealtimeServerEventRateLimitsUpdated (ex_openai.ex v2.0.0-beta2)
Emitted at the beginning of a Response to indicate the updated rate limits. When a Response is created some tokens will be "reserved" for the output tokens, the rate limits shown here reflect that reservation, which is then adjusted accordingly once the Response is completed.
Fields
:event_id- required -String.t()
The unique ID of the server event.:rate_limits- required -[{:%{}, [], [{{:optional, [], [:limit]}, {:integer, [], []}}, {{:optional, [], [:name]}, {:|, [], [:requests, :tokens]}}, {{:optional, [], [:remaining]}, {:integer, [], []}}, {{:optional, [], [:reset_seconds]}, {:number, [], []}}]}]
List of rate limit information.:type- required -:"rate_limits.updated"
The event type, must berate_limits.updated.
Allowed values:"rate_limits.updated"