View Source ExOpenAI.Components.RealtimeServerEventResponseAudioDone (ex_openai.ex v2.0.0-beta2)

Returned when the model-generated audio is done. Also emitted when a Response is interrupted, incomplete, or cancelled.

Fields

  • :content_index - required - integer()
    The index of the content part in the item's content array.

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :item_id - required - String.t()
    The ID of the item.

  • :output_index - required - integer()
    The index of the output item in the response.

  • :response_id - required - String.t()
    The ID of the response.

  • :type - required - :"response.output_audio.done"
    The event type, must be response.output_audio.done.
    Allowed values: "response.output_audio.done"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeServerEventResponseAudioDone{
  content_index: integer(),
  event_id: String.t(),
  item_id: String.t(),
  output_index: integer(),
  response_id: String.t(),
  type: :"response.output_audio.done"
}