View Source ExOpenAI.Components.RealtimeServerEventResponseContentPartDone (ex_openai.ex v2.0.0-beta2)

Returned when a content part is done streaming in an assistant message item. Also emitted when a Response is interrupted, incomplete, or cancelled.

Fields

  • :content_index - required - integer()
    The index of the content part in the item's content array.

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :item_id - required - String.t()
    The ID of the item.

  • :output_index - required - integer()
    The index of the output item in the response.

  • :part - required - {:%{}, [], [{{:optional, [], [:audio]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:optional, [], [:text]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:optional, [], [:transcript]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:optional, [], [:type]}, {:|, [], [:audio, :text]}}]}
    The content part that is done.

  • :response_id - required - String.t()
    The ID of the response.

  • :type - required - :"response.content_part.done"
    The event type, must be response.content_part.done.
    Allowed values: "response.content_part.done"

Summary

Types

@type t() :: %ExOpenAI.Components.RealtimeServerEventResponseContentPartDone{
  content_index: integer(),
  event_id: String.t(),
  item_id: String.t(),
  output_index: integer(),
  part: %{
    optional(:audio) => String.t(),
    optional(:text) => String.t(),
    optional(:transcript) => String.t(),
    optional(:type) => :audio | :text
  },
  response_id: String.t(),
  type: :"response.content_part.done"
}