View Source ExOpenAI.Components.RealtimeServerEventResponseFunctionCallArgumentsDone (ex_openai.ex v2.0.0-beta2)

Returned when the model-generated function call arguments are done streaming. Also emitted when a Response is interrupted, incomplete, or cancelled.

Fields

  • :arguments - required - String.t()
    The final arguments as a JSON string.

  • :call_id - required - String.t()
    The ID of the function call.

  • :event_id - required - String.t()
    The unique ID of the server event.

  • :item_id - required - String.t()
    The ID of the function call item.

  • :name - required - String.t()
    The name of the function that was called.

  • :output_index - required - integer()
    The index of the output item in the response.

  • :response_id - required - String.t()
    The ID of the response.

  • :type - required - :"response.function_call_arguments.done"
    The event type, must be response.function_call_arguments.done.
    Allowed values: "response.function_call_arguments.done"

Summary

Types

@type t() ::
  %ExOpenAI.Components.RealtimeServerEventResponseFunctionCallArgumentsDone{
    arguments: String.t(),
    call_id: String.t(),
    event_id: String.t(),
    item_id: String.t(),
    name: String.t(),
    output_index: integer(),
    response_id: String.t(),
    type: :"response.function_call_arguments.done"
  }