View Source ExOpenAI.Components.RealtimeServerEventResponseMCPCallInProgress (ex_openai.ex v2.0.0-beta2)
Returned when an MCP tool call has started and is in progress.
Fields
:event_id- required -String.t()
The unique ID of the server event.:item_id- required -String.t()
The ID of the MCP tool call item.:output_index- required -integer()
The index of the output item in the response.:type- required -:"response.mcp_call.in_progress"
The event type, must beresponse.mcp_call.in_progress.
Allowed values:"response.mcp_call.in_progress"