View Source ExOpenAI.Components.ResponseCodeInterpreterCallCompletedEvent (ex_openai.ex v2.0.0-beta2)
Emitted when the code interpreter call is completed.
Fields
:item_id- required -String.t()
The unique identifier of the code interpreter tool call item.:output_index- required -integer()
The index of the output item in the response for which the code interpreter call is completed.:sequence_number- required -integer()
The sequence number of this event, used to order streaming events.:type- required -:"response.code_interpreter_call.completed"
The type of the event. Alwaysresponse.code_interpreter_call.completed.
Allowed values:"response.code_interpreter_call.completed"