View Source ExOpenAI.Components.ResponseCustomToolCallInputDoneEvent (ex_openai.ex v2.0.0-beta2)

Event indicating that input for a custom tool call is complete.

Fields

  • :input - required - String.t()
    The complete input data for the custom tool call.

  • :item_id - required - String.t()
    Unique identifier for the API item associated with this event.

  • :output_index - required - integer()
    The index of the output this event applies to.

  • :sequence_number - required - integer()
    The sequence number of this event.

  • :type - required - :"response.custom_tool_call_input.done"
    The event type identifier.
    Allowed values: "response.custom_tool_call_input.done"

Summary

Types

@type t() :: %ExOpenAI.Components.ResponseCustomToolCallInputDoneEvent{
  input: String.t(),
  item_id: String.t(),
  output_index: integer(),
  sequence_number: integer(),
  type: :"response.custom_tool_call_input.done"
}