View Source ExOpenAI.Components.ResponseFileSearchCallSearchingEvent (ex_openai.ex v2.0.0-beta2)
Emitted when a file search is currently searching.
Fields
:item_id- required -String.t()
The ID of the output item that the file search call is initiated.:output_index- required -integer()
The index of the output item that the file search call is searching.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.file_search_call.searching"
The type of the event. Alwaysresponse.file_search_call.searching.
Allowed values:"response.file_search_call.searching"