View Source ExOpenAI.Components.ResponseFormatJsonSchemaSchema (ex_openai.ex v2.0.0-beta2)
The schema for the response format, described as a JSON Schema object. Learn how to build JSON schemas here.
Summary
Types
@type t() :: map()
The schema for the response format, described as a JSON Schema object. Learn how to build JSON schemas here.
@type t() :: map()