View Source ExOpenAI.Components.ResponseImageGenCallInProgressEvent (ex_openai.ex v2.0.0-beta2)
Emitted when an image generation tool call is in progress.
Fields
:item_id- required -String.t()
The unique identifier of the image generation item being processed.:output_index- required -integer()
The index of the output item in the response's output array.:sequence_number- required -integer()
The sequence number of the image generation item being processed.:type- required -:"response.image_generation_call.in_progress"
The type of the event. Always 'response.image_generation_call.in_progress'.
Allowed values:"response.image_generation_call.in_progress"