View Source ExOpenAI.Components.ResponseMCPCallArgumentsDoneEvent (ex_openai.ex v2.0.0-beta2)
Emitted when the arguments for an MCP tool call are finalized.
Fields
:arguments- required -String.t()
A JSON string containing the finalized arguments for the MCP tool call.:item_id- required -String.t()
The unique identifier of the MCP tool call item being processed.:output_index- required -integer()
The index of the output item in the response's output array.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.mcp_call_arguments.done"
The type of the event. Always 'response.mcp_call_arguments.done'.
Allowed values:"response.mcp_call_arguments.done"