View Source ExOpenAI.Components.ResponseRefusalDoneEvent (ex_openai.ex v2.0.0-beta2)
Emitted when refusal text is finalized.
Fields
:content_index- required -integer()
The index of the content part that the refusal text is finalized.:item_id- required -String.t()
The ID of the output item that the refusal text is finalized.:output_index- required -integer()
The index of the output item that the refusal text is finalized.:refusal- required -String.t()
The refusal text that is finalized.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.refusal.done"
The type of the event. Alwaysresponse.refusal.done.
Allowed values:"response.refusal.done"