View Source ExOpenAI.Components.ResponseWebSearchCallSearchingEvent (ex_openai.ex v2.0.0-beta2)
Emitted when a web search call is executing.
Fields
:item_id- required -String.t()
Unique ID for the output item associated with the web search call.:output_index- required -integer()
The index of the output item that the web search call is associated with.:sequence_number- required -integer()
The sequence number of the web search call being processed.:type- required -:"response.web_search_call.searching"
The type of the event. Alwaysresponse.web_search_call.searching.
Allowed values:"response.web_search_call.searching"