View Source ExOpenAI.Components.Role (ex_openai.ex v2.0.0-beta2)

Details about a role that can be assigned through the public Roles API.

Fields

  • :description - required - String.t() | any()
    Optional description of the role.

  • :id - required - String.t()
    Identifier for the role.

  • :name - required - String.t()
    Unique name for the role.

  • :object - required - :role
    Always role.
    Allowed values: "role"

  • :permissions - required - [String.t()]
    Permissions granted by the role.

  • :predefined_role - required - boolean()
    Whether the role is predefined and managed by OpenAI.

  • :resource_type - required - String.t()
    Resource type the role is bound to (for example api.organization or api.project).

Summary

Types

@type t() :: %ExOpenAI.Components.Role{
  description: String.t() | any(),
  id: String.t(),
  name: String.t(),
  object: :role,
  permissions: [String.t()],
  predefined_role: boolean(),
  resource_type: String.t()
}