View Source ExOpenAI.Components.RunGraderRequest (ex_openai.ex v2.0.0-beta2)

Module for representing the OpenAI schema RunGraderRequest.

Fields

  • :grader - required - map()
    The grader used for the fine-tuning job.

  • :item - optional - map()
    The dataset item provided to the grader. This will be used to populate the item namespace. See the guide for more details.

  • :model_sample - required - String.t()
    The model sample to be evaluated. This value will be used to populate the sample namespace. See the guide for more details. The output_json variable will be populated if the model sample is a valid JSON string.

Summary

Types

@type t() :: %ExOpenAI.Components.RunGraderRequest{
  grader: map(),
  item: map() | nil,
  model_sample: String.t()
}