View Source ExOpenAI.Components.RunStepDeltaStepDetailsToolCallsCodeOutputLogsObject (ex_openai.ex v2.0.0-beta2)

Text output from the Code Interpreter tool call as part of a run step.

Fields

  • :index - required - integer()
    The index of the output in the outputs array.

  • :logs - optional - String.t()
    The text output from the Code Interpreter tool call.

  • :type - required - :logs
    Always logs.
    Allowed values: "logs"

Summary

Types

@type t() ::
  %ExOpenAI.Components.RunStepDeltaStepDetailsToolCallsCodeOutputLogsObject{
    index: integer(),
    logs: String.t() | nil,
    type: :logs
  }