View Source ExOpenAI.Components.RunStepDeltaStepDetailsToolCallsFileSearchObject (ex_openai.ex v2.0.0-beta2)

Module for representing the OpenAI schema RunStepDeltaStepDetailsToolCallsFileSearchObject.

Fields

  • :file_search - required - map()
    For now, this is always going to be an empty object.

  • :id - optional - String.t()
    The ID of the tool call object.

  • :index - required - integer()
    The index of the tool call in the tool calls array.

  • :type - required - :file_search
    The type of tool call. This is always going to be file_search for this type of tool call.
    Allowed values: "file_search"

Summary

Types

@type t() :: %ExOpenAI.Components.RunStepDeltaStepDetailsToolCallsFileSearchObject{
  file_search: map(),
  id: String.t() | nil,
  index: integer(),
  type: :file_search
}