View Source ExOpenAI.Components.RunStepDeltaStepDetailsToolCallsObject (ex_openai.ex v2.0.0-beta)

Details of the tool call.

Fields

  • :tool_calls - optional - [any() | any() | any()]
    An array of tool calls the run step was involved in. These can be associated with one of three types of tools: code_interpreter, file_search, or function.

  • :type - required - :tool_calls
    Always tool_calls.
    Allowed values: "tool_calls"

Summary

Types