View Source ExOpenAI.Components.TextResponseFormatConfiguration (ex_openai.ex v2.0.0-beta2)

An object specifying the format that the model must output.

Configuring { "type": "json_schema" } enables Structured Outputs, which ensures the model will match your supplied JSON schema. Learn more in the Structured Outputs guide.

The default format is { "type": "text" } with no additional options.

Not recommended for gpt-4o and newer models:

Setting to { "type": "json_object" } enables the older JSON mode, which ensures the message the model generates is valid JSON. Using json_schema is preferred for models that support it.

Type

ExOpenAI.Components.ResponseFormatText.t() | ExOpenAI.Components.TextResponseFormatJsonSchema.t() | ExOpenAI.Components.ResponseFormatJsonObject.t()

Summary

Types