View Source ExOpenAI.Components.TextResponseFormatJsonSchema (ex_openai.ex v2.0.0-beta2)

JSON Schema response format. Used to generate structured JSON responses. Learn more about Structured Outputs.

Fields

  • :description - optional - String.t()
    A description of what the response format is for, used by the model to determine how to respond in the format.

  • :name - required - String.t()
    The name of the response format. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.

  • :schema - required - ExOpenAI.Components.ResponseFormatJsonSchemaSchema.t()

  • :strict - optional - boolean() | any()

  • :type - required - :json_schema
    The type of response format being defined. Always json_schema.
    Allowed values: "json_schema"

Summary

Types

@type t() :: %ExOpenAI.Components.TextResponseFormatJsonSchema{
  description: String.t() | nil,
  name: String.t(),
  schema: ExOpenAI.Components.ResponseFormatJsonSchemaSchema.t(),
  strict: (boolean() | any()) | nil,
  type: :json_schema
}