View Source ExOpenAI.Components.ToolChoiceCustom (ex_openai.ex v2.0.0-beta2)

Use this option to force the model to call a specific custom tool.

Fields

  • :name - required - String.t()
    The name of the custom tool to call.

  • :type - required - :custom
    For custom tool calling, the type is always custom.
    Allowed values: "custom"

Summary

Types

@type t() :: %ExOpenAI.Components.ToolChoiceCustom{name: String.t(), type: :custom}