View Source ExOpenAI.Components.TranscriptTextSegmentEvent (ex_openai.ex v2.0.0-beta2)
Emitted when a diarized transcription returns a completed segment with speaker information. Only emitted when you create a transcription with stream set to true and response_format set to diarized_json.
Fields
:end- required -number()
End timestamp of the segment in seconds.
Format:float:id- required -String.t()
Unique identifier for the segment.:speaker- required -String.t()
Speaker label for this segment.:start- required -number()
Start timestamp of the segment in seconds.
Format:float:text- required -String.t()
Transcript text for this segment.:type- required -:"transcript.text.segment"
The type of the event. Alwaystranscript.text.segment.
Allowed values:"transcript.text.segment"