View Source ExOpenAI.Components.UpdateConversationBody (ex_openai.ex v2.0.0-beta2)

Module for representing the OpenAI schema UpdateConversationBody.

Fields

  • :metadata - required - ExOpenAI.Components.Metadata.t()
    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
      Keys are strings with a maximum length of 64 characters. Values are strings         with a maximum length of 512 characters.

Summary

Types

@type t() :: %ExOpenAI.Components.UpdateConversationBody{
  metadata: ExOpenAI.Components.Metadata.t()
}