View Source ExOpenAI.Components.UrlCitationBody (ex_openai.ex v2.0.0-beta2)

A citation for a web resource used to generate a model response.

Fields

  • :end_index - required - integer()
    The index of the last character of the URL citation in the message.

  • :start_index - required - integer()
    The index of the first character of the URL citation in the message.

  • :title - required - String.t()
    The title of the web resource.

  • :type - required - :url_citation
    The type of the URL citation. Always url_citation.
    Allowed values: "url_citation"
    Default: "url_citation"

  • :url - required - String.t()
    The URL of the web resource.

Summary

Types

@type t() :: %ExOpenAI.Components.UrlCitationBody{
  end_index: integer(),
  start_index: integer(),
  title: String.t(),
  type: :url_citation,
  url: String.t()
}