View Source ExOpenAI.StreamingClient behaviour (ex_openai.ex v2.0.0-beta2)
Summary
Functions
Recursively atomizes map keys (string keys become atoms), walking lists and maps. Intended for streaming fallback when we skip full struct conversion.
Returns a specification to start this module under a supervisor.
Forwards the given response back to the receiver If receiver is a PID, will use GenServer.cast to send If receiver is a function, will call the function directly
Callback implementation for GenServer.init/1.
Callbacks
Functions
Recursively atomizes map keys (string keys become atoms), walking lists and maps. Intended for streaming fallback when we skip full struct conversion.
Returns a specification to start this module under a supervisor.
See Supervisor.
Forwards the given response back to the receiver If receiver is a PID, will use GenServer.cast to send If receiver is a function, will call the function directly
Callback implementation for GenServer.init/1.