View Source ExOpenAI.Components.ApplyPatchCreateFileOperationParam (ex_openai.ex v2.0.0-beta2)
Instruction for creating a new file via the apply_patch tool.
Fields
:diff- required -String.t()
Unified diff content to apply when creating the file.
Constraints: maxLength: 10485760:path- required -String.t()
Path of the file to create relative to the workspace root.
Constraints: minLength: 1:type- required -:create_file
The operation type. Alwayscreate_file.
Allowed values:"create_file"
Default:"create_file"