View Source ExOpenAI.Components.ApplyPatchToolCall (ex_openai.ex v2.0.0-beta2)
A tool call that applies file diffs by creating, deleting, or updating files.
Fields
:call_id- required -String.t()
The unique ID of the apply patch tool call generated by the model.:created_by- optional -String.t()
The ID of the entity that created this tool call.:id- required -String.t()
The unique ID of the apply patch tool call. Populated when this item is returned via API.:operation- required -ExOpenAI.Components.ApplyPatchCreateFileOperation.t() | ExOpenAI.Components.ApplyPatchDeleteFileOperation.t() | ExOpenAI.Components.ApplyPatchUpdateFileOperation.t()
One of the create_file, delete_file, or update_file operations applied via apply_patch.:status- required -ExOpenAI.Components.ApplyPatchCallStatus.t()
The status of the apply patch tool call. One ofin_progressorcompleted.:type- required -:apply_patch_call
The type of the item. Alwaysapply_patch_call.
Allowed values:"apply_patch_call"
Default:"apply_patch_call"
Summary
Types
@type t() :: %ExOpenAI.Components.ApplyPatchToolCall{ call_id: String.t(), created_by: String.t() | nil, id: String.t(), operation: (ExOpenAI.Components.ApplyPatchCreateFileOperation.t() | ExOpenAI.Components.ApplyPatchDeleteFileOperation.t()) | ExOpenAI.Components.ApplyPatchUpdateFileOperation.t(), status: ExOpenAI.Components.ApplyPatchCallStatus.t(), type: :apply_patch_call }