View Source ExOpenAI.Components.ApplyPatchToolCallItemParam (ex_openai.ex v2.0.0-beta2)
A tool call representing a request to create, delete, or update files using diff patches.
Fields
:call_id- required -String.t()
The unique ID of the apply patch tool call generated by the model.
Constraints: minLength: 1, maxLength: 64:id- optional -String.t() | any():operation- required -ExOpenAI.Components.ApplyPatchOperationParam.t()
The specific create, delete, or update instruction for the apply_patch tool call.:status- required -ExOpenAI.Components.ApplyPatchCallStatusParam.t()
The status of the apply patch tool call. One ofin_progressorcompleted.:type- required -:apply_patch_call
The type of the item. Alwaysapply_patch_call.
Allowed values:"apply_patch_call"
Default:"apply_patch_call"
Summary
Types
@type t() :: %ExOpenAI.Components.ApplyPatchToolCallItemParam{ call_id: String.t(), id: (String.t() | any()) | nil, operation: ExOpenAI.Components.ApplyPatchOperationParam.t(), status: ExOpenAI.Components.ApplyPatchCallStatusParam.t(), type: :apply_patch_call }