View Source ExOpenAI.Components.ApplyPatchToolCallOutputItemParam (ex_openai.ex v2.0.0-beta2)
The streamed output emitted by an apply patch tool call.
Fields
:call_id- required -String.t()
The unique ID of the apply patch tool call generated by the model.
Constraints: minLength: 1, maxLength: 64:id- optional -String.t() | any():output- optional -String.t() | any():status- required -ExOpenAI.Components.ApplyPatchCallOutputStatusParam.t()
The status of the apply patch tool call output. One ofcompletedorfailed.:type- required -:apply_patch_call_output
The type of the item. Alwaysapply_patch_call_output.
Allowed values:"apply_patch_call_output"
Default:"apply_patch_call_output"