View Source ExOpenAI.Components.ChatCompletionRequestSystemMessage (ex_openai.ex v2.0.0-beta2)
Developer-provided instructions that the model should follow, regardless of
messages sent by the user. With o1 models and newer, use developer messages
for this purpose instead.
Fields
:content- required -String.t() | [ExOpenAI.Components.ChatCompletionRequestSystemMessageContentPart.t()]
The contents of the system message.:name- optional -String.t()
An optional name for the participant. Provides the model information to differentiate between participants of the same role.:role- required -:system
The role of the messages author, in this casesystem.
Allowed values:"system"
Summary
Types
@type t() :: %ExOpenAI.Components.ChatCompletionRequestSystemMessage{ content: String.t() | [ExOpenAI.Components.ChatCompletionRequestSystemMessageContentPart.t()], name: String.t() | nil, role: :system }