View Source ExOpenAI.Components.ChatCompletionToolChoiceOption (ex_openai.ex v2.0.0-beta2)

Controls which (if any) tool is called by the model. none means the model will not call any tool and instead generates a message. auto means the model can pick between generating a message or calling one or more tools. required means the model must call one or more tools. Specifying a particular tool via {"type": "function", "function": {"name": "my_function"}} forces the model to call that tool.

none is the default when no tools are present. auto is the default if tools are present.

Type

:none | :auto | :required | ExOpenAI.Components.ChatCompletionAllowedToolsChoice.t() | ExOpenAI.Components.ChatCompletionNamedToolChoice.t() | ExOpenAI.Components.ChatCompletionNamedToolChoiceCustom.t()

Summary

Types