View Source ExOpenAI.Components.ComparisonFilter (ex_openai.ex v2.0.0-beta2)
A filter used to compare a specified attribute key to a given value using a defined comparison operation.
Fields
:key- required -String.t()
The key to compare against the value.:type- required -:eq | :ne | :gt | :gte | :lt | :lte | :in | :nin
Specifies the comparison operator:eq,ne,gt,gte,lt,lte,in,nin.
eq: equalsne: not equalgt: greater thangte: greater than or equallt: less thanlte: less than or equalin: innin: not in
Allowed values:"eq","ne","gt","gte","lt","lte","in","nin"
Default:"eq"
:value- required -String.t() | number() | boolean() | [String.t() | number()]
The value to compare against the attribute key; supports string, number, or boolean types.