View Source ExOpenAI.Components.ComputerScreenshotContent (ex_openai.ex v2.0.0-beta2)
A screenshot of a computer.
Fields
:detail- required -ExOpenAI.Components.ImageDetail.t()
The detail level of the screenshot image to be sent to the model. One ofhigh,low,auto, ororiginal. Defaults toauto.:file_id- required -String.t() | any():image_url- required -String.t() | any():type- required -:computer_screenshot
Specifies the event type. For a computer screenshot, this property is always set tocomputer_screenshot.
Allowed values:"computer_screenshot"
Default:"computer_screenshot"
Summary
Types
@type t() :: %ExOpenAI.Components.ComputerScreenshotContent{ detail: ExOpenAI.Components.ImageDetail.t(), file_id: String.t() | any(), image_url: String.t() | any(), type: :computer_screenshot }