View Source ExOpenAI.Components.ComputerScreenshotImage (ex_openai.ex v2.0.0-beta2)
A computer screenshot image used with the computer use tool.
Fields
:file_id- optional -String.t()
The identifier of an uploaded file that contains the screenshot.:image_url- optional -String.t()
The URL of the screenshot image.:type- required -:computer_screenshot
Specifies the event type. For a computer screenshot, this property is always set tocomputer_screenshot.
Allowed values:"computer_screenshot"
Default:"computer_screenshot"