View Source ExOpenAI.Components.ContainerAutoParam (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema ContainerAutoParam.
Fields
:file_ids- optional -[String.t()]
An optional list of uploaded files to make available to your code.
Constraints: maxItems: 50:memory_limit- optional -ExOpenAI.Components.ContainerMemoryLimit.t() | any():network_policy- optional -ExOpenAI.Components.ContainerNetworkPolicyDisabledParam.t() | ExOpenAI.Components.ContainerNetworkPolicyAllowlistParam.t()
Network access policy for the container.:skills- optional -[ExOpenAI.Components.SkillReferenceParam.t() | ExOpenAI.Components.InlineSkillParam.t()]
An optional list of skills referenced by id or inline data.
Constraints: maxItems: 200:type- required -:container_auto
Automatically creates a container for this request
Allowed values:"container_auto"
Default:"container_auto"
Summary
Types
@type t() :: %ExOpenAI.Components.ContainerAutoParam{ file_ids: [String.t()] | nil, memory_limit: (ExOpenAI.Components.ContainerMemoryLimit.t() | any()) | nil, network_policy: (ExOpenAI.Components.ContainerNetworkPolicyDisabledParam.t() | ExOpenAI.Components.ContainerNetworkPolicyAllowlistParam.t()) | nil, skills: [ ExOpenAI.Components.SkillReferenceParam.t() | ExOpenAI.Components.InlineSkillParam.t() ] | nil, type: :container_auto }