View Source ExOpenAI.Components.ContainerFileCitationBody (ex_openai.ex v2.0.0-beta2)
A citation for a container file used to generate a model response.
Fields
:container_id- required -String.t()
The ID of the container file.:end_index- required -integer()
The index of the last character of the container file citation in the message.:file_id- required -String.t()
The ID of the file.:filename- required -String.t()
The filename of the container file cited.:start_index- required -integer()
The index of the first character of the container file citation in the message.:type- required -:container_file_citation
The type of the container file citation. Alwayscontainer_file_citation.
Allowed values:"container_file_citation"
Default:"container_file_citation"