View Source ExOpenAI.Components.ConversationParam (ex_openai.ex v2.0.0-beta2)

The conversation that this response belongs to. Items from this conversation are prepended to input_items for this response request. Input items and output items from this response are automatically added to this conversation after this response completes.

Type

String.t() | :"Elixir.ExOpenAI.Components.ConversationParam-2".t()

Summary

Types

@type t() :: String.t() | :"Elixir.ExOpenAI.Components.ConversationParam-2".t()