View Source ExOpenAI.Components.ConversationResource (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema ConversationResource.
Fields
:created_at- required -integer()
The time at which the conversation was created, measured in seconds since the Unix epoch.:id- required -String.t()
The unique ID of the conversation.:metadata- required -any()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.:object- required -:conversation
The object type, which is alwaysconversation.
Allowed values:"conversation"
Default:"conversation"