View Source ExOpenAI.Components.CreateEvalCustomDataSourceConfig (ex_openai.ex v2.0.0-beta2)
A CustomDataSourceConfig object that defines the schema for the data source used for the evaluation runs. This schema is used to define the shape of the data that will be:
- Used to define your testing criteria and
- What data is required when creating a run
Fields
:include_sample_schema- optional -boolean()
Whether the eval should expect you to populate the sample namespace (ie, by generating responses off of your data source)
Default:false:item_schema- required -map()
The json schema for each row in the data source.:type- required -:custom
The type of data source. Alwayscustom.
Allowed values:"custom"
Default:"custom"