View Source ExOpenAI.Components.CreateEvalLabelModelGrader (ex_openai.ex v2.0.0-beta2)
A LabelModelGrader object which uses a model to assign labels to each item in the evaluation.
Fields
:input- required -[ExOpenAI.Components.CreateEvalItem.t()]
A list of chat messages forming the prompt or context. May include variable references to theitemnamespace, ie {{item.name}}.:labels- required -[String.t()]
The labels to classify to each item in the evaluation.:model- required -String.t()
The model to use for the evaluation. Must support structured outputs.:name- required -String.t()
The name of the grader.:passing_labels- required -[String.t()]
The labels that indicate a passing result. Must be a subset of labels.:type- required -:label_model
The object type, which is alwayslabel_model.
Allowed values:"label_model"
Summary
Types
@type t() :: %ExOpenAI.Components.CreateEvalLabelModelGrader{ input: [ExOpenAI.Components.CreateEvalItem.t()], labels: [String.t()], model: String.t(), name: String.t(), passing_labels: [String.t()], type: :label_model }