View Source ExOpenAI.Components.CreateTranscriptionResponseJson (ex_openai.ex v2.0.0-beta2)
Represents a transcription response returned by model, based on the provided input.
Fields
:logprobs- optional -[{:%{}, [], [{{:optional, [], [:bytes]}, {:list, [], [{:number, [], []}]}}, {{:optional, [], [:logprob]}, {:number, [], []}}, {{:optional, [], [:token]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}]
The log probabilities of the tokens in the transcription. Only returned with the modelsgpt-4o-transcribeandgpt-4o-mini-transcribeiflogprobsis added to theincludearray.:text- required -String.t()
The transcribed text.:usage- optional -map()
Token usage statistics for the request.