View Source ExOpenAI.Components.CreateVectorStoreFileBatchRequest (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema CreateVectorStoreFileBatchRequest.
Fields
:attributes- optional -ExOpenAI.Components.VectorStoreFileAttributes.t():chunking_strategy- optional -ExOpenAI.Components.ChunkingStrategyRequestParam.t():file_ids- optional -[String.t()]
A list of File IDs that the vector store should use. Useful for tools likefile_searchthat can access files. Ifattributesorchunking_strategyare provided, they will be applied to all files in the batch. The maximum batch size is 2000 files. This endpoint is recommended for multi-file ingestion and helps reduce per-vector-store write request pressure. Mutually exclusive withfiles.
Constraints: minItems: 1, maxItems: 2000:files- optional -[ExOpenAI.Components.CreateVectorStoreFileRequest.t()]
A list of objects that each include afile_idplus optionalattributesorchunking_strategy. Use this when you need to override metadata for specific files. The globalattributesorchunking_strategywill be ignored and must be specified for each file. The maximum batch size is 2000 files. This endpoint is recommended for multi-file ingestion and helps reduce per-vector-store write request pressure. Mutually exclusive withfile_ids.
Constraints: minItems: 1, maxItems: 2000
Summary
Types
@type t() :: %ExOpenAI.Components.CreateVectorStoreFileBatchRequest{ attributes: ExOpenAI.Components.VectorStoreFileAttributes.t() | nil, chunking_strategy: ExOpenAI.Components.ChunkingStrategyRequestParam.t() | nil, file_ids: [String.t()] | nil, files: [ExOpenAI.Components.CreateVectorStoreFileRequest.t()] | nil }