View Source ExOpenAI.Components.CustomToolCallOutput (ex_openai.ex v2.0.0-beta2)
The output of a custom tool call from your code, being sent back to the model.
Fields
:call_id- required -String.t()
The call ID, used to map this custom tool call output to a custom tool call.:id- optional -String.t()
The unique ID of the custom tool call output in the OpenAI platform.:output- required -String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()]
The output from the custom tool call generated by your code. Can be a string or an list of output content.:type- required -:custom_tool_call_output
The type of the custom tool call output. Alwayscustom_tool_call_output.
Allowed values:"custom_tool_call_output"
Summary
Types
@type t() :: %ExOpenAI.Components.CustomToolCallOutput{ call_id: String.t(), id: String.t() | nil, output: String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()], type: :custom_tool_call_output }