View Source ExOpenAI.Components.CustomToolCallResource (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema CustomToolCallResource.
Fields
:call_id- required -String.t()
An identifier used to map this custom tool call to a tool call output.:created_by- optional -String.t()
The identifier of the actor that created the item.:id- required -String.t()
The unique ID of the custom tool call item.:input- required -String.t()
The input for the custom tool call generated by the model.:name- required -String.t()
The name of the custom tool being called.:namespace- optional -String.t()
The namespace of the custom tool being called.:status- required -ExOpenAI.Components.FunctionCallStatus.t()
The status of the item. One ofin_progress,completed, orincomplete. Populated when items are returned via API.:type- required -:custom_tool_call
The type of the custom tool call. Alwayscustom_tool_call.
Allowed values:"custom_tool_call"