View Source ExOpenAI.Components.DragParam (ex_openai.ex v2.0.0-beta2)
A drag action.
Fields
:keys- optional -[String.t()] | any():path- required -[ExOpenAI.Components.CoordParam.t()]
An array of coordinates representing the path of the drag action. Coordinates will appear as an array of objects, eg[ { x: 100, y: 200 }, { x: 200, y: 300 } ]:type- required -:drag
Specifies the event type. For a drag action, this property is always set todrag.
Allowed values:"drag"
Default:"drag"
Summary
Types
@type t() :: %ExOpenAI.Components.DragParam{ keys: ([String.t()] | any()) | nil, path: [ExOpenAI.Components.CoordParam.t()], type: :drag }