View Source ExOpenAI.Components.EvalItem (ex_openai.ex v2.0.0-beta2)
A message input to the model with a role indicating instruction following
hierarchy. Instructions given with the developer or system role take
precedence over instructions given with the user role. Messages with the
assistant role are presumed to have been generated by the model in previous
interactions.
Fields
:content- required -ExOpenAI.Components.EvalItemContent.t():role- required -:user | :assistant | :system | :developer
The role of the message input. One ofuser,assistant,system, ordeveloper.
Allowed values:"user","assistant","system","developer":type- optional -:message
The type of the message input. Alwaysmessage.
Allowed values:"message"
Summary
Types
@type t() :: %ExOpenAI.Components.EvalItem{ content: ExOpenAI.Components.EvalItemContent.t(), role: ((:user | :assistant) | :system) | :developer, type: :message | nil }