View Source ExOpenAI.Components.FileSearchRankingOptions (ex_openai.ex v2.0.0-beta2)
The ranking options for the file search. If not specified, the file search tool will use the auto ranker and a score_threshold of 0.
See the file search tool documentation for more information.
Fields
:ranker- optional -ExOpenAI.Components.FileSearchRanker.t():score_threshold- required -number()
The score threshold for the file search. All values must be a floating point number between 0 and 1.
Constraints: minimum: 0, maximum: 1
Summary
Types
@type t() :: %ExOpenAI.Components.FileSearchRankingOptions{ ranker: ExOpenAI.Components.FileSearchRanker.t() | nil, score_threshold: number() }