View Source ExOpenAI.Components.FunctionShellCallItemParam (ex_openai.ex v2.0.0-beta2)
A tool representing a request to execute one or more shell commands.
Fields
:action- required -ExOpenAI.Components.FunctionShellActionParam.t()
The shell commands and limits that describe how to run the tool call.:call_id- required -String.t()
The unique ID of the shell tool call generated by the model.
Constraints: minLength: 1, maxLength: 64:environment- optional -ExOpenAI.Components.LocalEnvironmentParam.t() | ExOpenAI.Components.ContainerReferenceParam.t() | any():id- optional -String.t() | any():status- optional -ExOpenAI.Components.FunctionShellCallItemStatus.t() | any():type- required -:shell_call
The type of the item. Alwaysshell_call.
Allowed values:"shell_call"
Default:"shell_call"
Summary
Types
@type t() :: %ExOpenAI.Components.FunctionShellCallItemParam{ action: ExOpenAI.Components.FunctionShellActionParam.t(), call_id: String.t(), environment: ((ExOpenAI.Components.LocalEnvironmentParam.t() | ExOpenAI.Components.ContainerReferenceParam.t()) | any()) | nil, id: (String.t() | any()) | nil, status: (ExOpenAI.Components.FunctionShellCallItemStatus.t() | any()) | nil, type: :shell_call }