View Source ExOpenAI.Components.FunctionShellCallOutput (ex_openai.ex v2.0.0-beta2)
The output of a shell tool call that was emitted.
Fields
:call_id- required -String.t()
The unique ID of the shell tool call generated by the model.:created_by- optional -String.t()
The identifier of the actor that created the item.:id- required -String.t()
The unique ID of the shell call output. Populated when this item is returned via API.:max_output_length- required -integer() | any():output- required -[ExOpenAI.Components.FunctionShellCallOutputContent.t()]
An array of shell call output contents:status- required -ExOpenAI.Components.LocalShellCallOutputStatusEnum.t()
The status of the shell call output. One ofin_progress,completed, orincomplete.:type- required -:shell_call_output
The type of the shell call output. Alwaysshell_call_output.
Allowed values:"shell_call_output"
Default:"shell_call_output"
Summary
Types
@type t() :: %ExOpenAI.Components.FunctionShellCallOutput{ call_id: String.t(), created_by: String.t() | nil, id: String.t(), max_output_length: integer() | any(), output: [ExOpenAI.Components.FunctionShellCallOutputContent.t()], status: ExOpenAI.Components.LocalShellCallOutputStatusEnum.t(), type: :shell_call_output }