View Source ExOpenAI.Components.FunctionToolCallOutput (ex_openai.ex v2.0.0-beta2)
The output of a function tool call.
Fields
:call_id- required -String.t()
The unique ID of the function tool call generated by the model.:id- optional -String.t()
The unique ID of the function tool call output. Populated when this item is returned via API.:output- required -String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()]
The output from the function call generated by your code. Can be a string or an list of output content.:status- optional -:in_progress | :completed | :incomplete
The status of the item. One ofin_progress,completed, orincomplete. Populated when items are returned via API.
Allowed values:"in_progress","completed","incomplete":type- required -:function_call_output
The type of the function tool call output. Alwaysfunction_call_output.
Allowed values:"function_call_output"
Summary
Types
@type t() :: %ExOpenAI.Components.FunctionToolCallOutput{ call_id: String.t(), id: String.t() | nil, output: String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()], status: ((:in_progress | :completed) | :incomplete) | nil, type: :function_call_output }