View Source ExOpenAI.Components.FunctionToolCallOutputResource (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema FunctionToolCallOutputResource.
Fields
:call_id- required -String.t()
The unique ID of the function tool call generated by the model.:created_by- optional -String.t()
The identifier of the actor that created the item.:id- required -String.t()
The unique ID of the function call tool output.:output- required -String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()]
The output from the function call generated by your code. Can be a string or an list of output content.:status- required -ExOpenAI.Components.FunctionCallOutputStatusEnum.t()
The status of the item. One ofin_progress,completed, orincomplete. Populated when items are returned via API.:type- required -:function_call_output
The type of the function tool call output. Alwaysfunction_call_output.
Allowed values:"function_call_output"
Summary
Types
@type t() :: %ExOpenAI.Components.FunctionToolCallOutputResource{ call_id: String.t(), created_by: String.t() | nil, id: String.t(), output: String.t() | [ExOpenAI.Components.FunctionAndCustomToolCallOutput.t()], status: ExOpenAI.Components.FunctionCallOutputStatusEnum.t(), type: :function_call_output }