View Source ExOpenAI.Components.FunctionToolCallResource (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema FunctionToolCallResource.
Fields
:arguments- required -String.t()
A JSON string of the arguments to pass to the function.:call_id- required -String.t()
The unique ID of the function tool call generated by the model.:created_by- optional -String.t()
The identifier of the actor that created the item.:id- required -String.t()
The unique ID of the function tool call.:name- required -String.t()
The name of the function to run.:namespace- optional -String.t()
The namespace of the function to run.:status- required -ExOpenAI.Components.FunctionCallStatus.t()
The status of the item. One ofin_progress,completed, orincomplete. Populated when items are returned via API.:type- required -:function_call
The type of the function tool call. Alwaysfunction_call.
Allowed values:"function_call"