View Source ExOpenAI.Components.HybridSearchOptions (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema HybridSearchOptions.
Fields
:embedding_weight- required -number()
The weight of the embedding in the reciprocal ranking fusion.:text_weight- required -number()
The weight of the text in the reciprocal ranking fusion.