View Source ExOpenAI.Components.IncludeEnum (ex_openai.ex v2.0.0-beta2)
Specify additional output data to include in the model response. Currently supported values are:
web_search_call.action.sources: Include the sources of the web search tool call.code_interpreter_call.outputs: Includes the outputs of python code execution in code interpreter tool call items.computer_call_output.output.image_url: Include image urls from the computer call output.file_search_call.results: Include the search results of the file search tool call.message.input_image.image_url: Include image urls from the input message.message.output_text.logprobs: Include logprobs with assistant messages.reasoning.encrypted_content: Includes an encrypted version of reasoning tokens in reasoning item outputs. This enables reasoning items to be used in multi-turn conversations when using the Responses API statelessly (like when thestoreparameter is set tofalse, or when an organization is enrolled in the zero data retention program).
Type
:"file_search_call.results" | :"web_search_call.action.sources" | :"message.input_image.image_url" | :"computer_call_output.output.image_url" | :"code_interpreter_call.outputs" | :"reasoning.encrypted_content" | :"message.output_text.logprobs"
Allowed Values
"file_search_call.results", "web_search_call.action.sources", "message.input_image.image_url", "computer_call_output.output.image_url", "code_interpreter_call.outputs", "reasoning.encrypted_content", "message.output_text.logprobs"
Summary
Types
@type t() ::
(((((:"file_search_call.results" | :"web_search_call.action.sources")
| :"message.input_image.image_url")
| :"computer_call_output.output.image_url")
| :"code_interpreter_call.outputs")
| :"reasoning.encrypted_content")
| :"message.output_text.logprobs"