View Source ExOpenAI.Components.InviteProjectGroupBody (ex_openai.ex v2.0.0-beta2)
Request payload for granting a group access to a project.
Fields
:group_id- required -String.t()
Identifier of the group to add to the project.:role- required -String.t()
Identifier of the project role to grant to the group.