View Source ExOpenAI.Components.LocalShellToolCallOutput (ex_openai.ex v2.0.0-beta2)
The output of a local shell tool call.
Fields
:id- required -String.t()
The unique ID of the local shell tool call generated by the model.:output- required -String.t()
A JSON string of the output of the local shell tool call.:status- optional -:in_progress | :completed | :incomplete | any():type- required -:local_shell_call_output
The type of the local shell tool call output. Alwayslocal_shell_call_output.
Allowed values:"local_shell_call_output"