View Source ExOpenAI.Components.MessageDeltaContentTextObject (ex_openai.ex v2.0.0-beta2)
The text content that is part of a message.
Fields
:index- required -integer()
The index of the content part in the message.:text- optional -{:%{}, [], [{{:optional, [], [:annotations]}, {:list, [], [{:|, [], [{{:., [], [ExOpenAI.Components.MessageDeltaContentTextAnnotationsFileCitationObject, :t]}, [], []}, {{:., [], [ExOpenAI.Components.MessageDeltaContentTextAnnotationsFilePathObject, :t]}, [], []}]}]}}, {{:optional, [], [:value]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}:type- required -:text
Alwaystext.
Allowed values:"text"
Summary
Types
@type t() :: %ExOpenAI.Components.MessageDeltaContentTextObject{ index: integer(), text: %{ optional(:annotations) => [ ExOpenAI.Components.MessageDeltaContentTextAnnotationsFileCitationObject.t() | ExOpenAI.Components.MessageDeltaContentTextAnnotationsFilePathObject.t() ], optional(:value) => String.t() } | nil, type: :text }