View Source ExOpenAI.Components.RealtimeBetaClientEventConversationItemDelete (ex_openai.ex v2.0.0-beta2)
Send this event when you want to remove any item from the conversation
history. The server will respond with a conversation.item.deleted event,
unless the item does not exist in the conversation history, in which case the
server will respond with an error.
Fields
:event_id- optional -String.t()
Optional client-generated ID used to identify this event.:item_id- required -String.t()
The ID of the item to delete.:type- required -:"conversation.item.delete"
The event type, must beconversation.item.delete.
Allowed values:"conversation.item.delete"