View Source ExOpenAI.Components.RealtimeBetaServerEventResponseMCPCallArgumentsDone (ex_openai.ex v2.0.0-beta2)
Returned when MCP tool call arguments are finalized during response generation.
Fields
:arguments- required -String.t()
The final JSON-encoded arguments string.:event_id- required -String.t()
The unique ID of the server event.:item_id- required -String.t()
The ID of the MCP tool call item.:output_index- required -integer()
The index of the output item in the response.:response_id- required -String.t()
The ID of the response.:type- required -:"response.mcp_call_arguments.done"
The event type, must beresponse.mcp_call_arguments.done.
Allowed values:"response.mcp_call_arguments.done"