View Source ExOpenAI.Components.RealtimeConversationItemFunctionCall (ex_openai.ex v2.0.0-beta2)
A function call item in a Realtime conversation.
Fields
:arguments- required -String.t()
The arguments of the function call. This is a JSON-encoded string representing the arguments passed to the function, for example{"arg1": "value1", "arg2": 42}.:call_id- optional -String.t()
The ID of the function call.:id- optional -String.t()
The unique ID of the item. This may be provided by the client or generated by the server.:name- required -String.t()
The name of the function being called.:object- optional -:"realtime.item"
Identifier for the API object being returned - alwaysrealtime.item. Optional when creating a new item.
Allowed values:"realtime.item":status- optional -:completed | :incomplete | :in_progress
The status of the item. Has no effect on the conversation.
Allowed values:"completed","incomplete","in_progress":type- required -:function_call
The type of the item. Alwaysfunction_call.
Allowed values:"function_call"