View Source ExOpenAI.Components.RealtimeFunctionTool (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema RealtimeFunctionTool.
Fields
:description- optional -String.t()
The description of the function, including guidance on when and how to call it, and guidance about what to tell the user when calling (if anything).:name- optional -String.t()
The name of the function.:parameters- optional -map()
Parameters of the function in JSON Schema.:type- optional -:function
The type of the tool, i.e.function.
Allowed values:"function"