View Source ExOpenAI.Components.RealtimeServerEventConversationItemDeleted (ex_openai.ex v2.0.0-beta2)
Returned when an item in the conversation is deleted by the client with a
conversation.item.delete event. This event is used to synchronize the
server's understanding of the conversation history with the client's view.
Fields
:event_id- required -String.t()
The unique ID of the server event.:item_id- required -String.t()
The ID of the item that was deleted.:type- required -:"conversation.item.deleted"
The event type, must beconversation.item.deleted.
Allowed values:"conversation.item.deleted"