View Source ExOpenAI.Components.RealtimeServerEventConversationItemInputAudioTranscriptionDelta (ex_openai.ex v2.0.0-beta2)
Returned when the text value of an input audio transcription content part is updated with incremental transcription results.
Fields
:content_index- optional -integer()
The index of the content part in the item's content array.:delta- optional -String.t()
The text delta.:event_id- required -String.t()
The unique ID of the server event.:item_id- required -String.t()
The ID of the item containing the audio that is being transcribed.:logprobs- optional -[ExOpenAI.Components.LogProbProperties.t()] | any():type- required -:"conversation.item.input_audio_transcription.delta"
The event type, must beconversation.item.input_audio_transcription.delta.
Allowed values:"conversation.item.input_audio_transcription.delta"
Summary
Types
@type t() :: %ExOpenAI.Components.RealtimeServerEventConversationItemInputAudioTranscriptionDelta{ content_index: integer() | nil, delta: String.t() | nil, event_id: String.t(), item_id: String.t(), logprobs: ([ExOpenAI.Components.LogProbProperties.t()] | any()) | nil, type: :"conversation.item.input_audio_transcription.delta" }