View Source ExOpenAI.Components.RealtimeServerEventResponseDone (ex_openai.ex v2.0.0-beta2)
Returned when a Response is done streaming. Always emitted, no matter the
final state. The Response object included in the response.done event will
include all output Items in the Response but will omit the raw audio data.
Clients should check the status field of the Response to determine if it was successful
(completed) or if there was another outcome: cancelled, failed, or incomplete.
A response will contain all output items that were generated during the response, excluding any audio content.
Fields
:event_id- required -String.t()
The unique ID of the server event.:response- required -ExOpenAI.Components.RealtimeResponse.t():type- required -:"response.done"
The event type, must beresponse.done.
Allowed values:"response.done"
Summary
Types
@type t() :: %ExOpenAI.Components.RealtimeServerEventResponseDone{ event_id: String.t(), response: ExOpenAI.Components.RealtimeResponse.t(), type: :"response.done" }