View Source ExOpenAI.Components.RealtimeServerEventResponseMCPCallArgumentsDelta (ex_openai.ex v2.0.0-beta2)
Returned when MCP tool call arguments are updated during response generation.
Fields
:delta- required -String.t()
The JSON-encoded arguments delta.:event_id- required -String.t()
The unique ID of the server event.:item_id- required -String.t()
The ID of the MCP tool call item.:obfuscation- optional -String.t() | any():output_index- required -integer()
The index of the output item in the response.:response_id- required -String.t()
The ID of the response.:type- required -:"response.mcp_call_arguments.delta"
The event type, must beresponse.mcp_call_arguments.delta.
Allowed values:"response.mcp_call_arguments.delta"