View Source ExOpenAI.Components.ReasoningItem (ex_openai.ex v2.0.0-beta2)
A description of the chain of thought used by a reasoning model while generating
a response. Be sure to include these items in your input to the Responses API
for subsequent turns of a conversation if you are manually
managing context.
Fields
:content- optional -[ExOpenAI.Components.ReasoningTextContent.t()]
Reasoning text content.:encrypted_content- optional -String.t() | any():id- required -String.t()
The unique identifier of the reasoning content.:status- optional -:in_progress | :completed | :incomplete
The status of the item. One ofin_progress,completed, orincomplete. Populated when items are returned via API.
Allowed values:"in_progress","completed","incomplete":summary- required -[ExOpenAI.Components.SummaryTextContent.t()]
Reasoning summary content.:type- required -:reasoning
The type of the object. Alwaysreasoning.
Allowed values:"reasoning"
Summary
Types
@type t() :: %ExOpenAI.Components.ReasoningItem{ content: [ExOpenAI.Components.ReasoningTextContent.t()] | nil, encrypted_content: (String.t() | any()) | nil, id: String.t(), status: ((:in_progress | :completed) | :incomplete) | nil, summary: [ExOpenAI.Components.SummaryTextContent.t()], type: :reasoning }