View Source ExOpenAI.Components.ResponseCodeInterpreterCallCodeDoneEvent (ex_openai.ex v2.0.0-beta2)
Emitted when the code snippet is finalized by the code interpreter.
Fields
:code- required -String.t()
The final code snippet output by the code interpreter.:item_id- required -String.t()
The unique identifier of the code interpreter tool call item.:output_index- required -integer()
The index of the output item in the response for which the code is finalized.:sequence_number- required -integer()
The sequence number of this event, used to order streaming events.:type- required -:"response.code_interpreter_call_code.done"
The type of the event. Alwaysresponse.code_interpreter_call_code.done.
Allowed values:"response.code_interpreter_call_code.done"