View Source ExOpenAI.Components.ResponseContentPartDoneEvent (ex_openai.ex v2.0.0-beta2)
Emitted when a content part is done.
Fields
:content_index- required -integer()
The index of the content part that is done.:item_id- required -String.t()
The ID of the output item that the content part was added to.:output_index- required -integer()
The index of the output item that the content part was added to.:part- required -ExOpenAI.Components.OutputContent.t()
The content part that is done.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.content_part.done"
The type of the event. Alwaysresponse.content_part.done.
Allowed values:"response.content_part.done"
Summary
Types
@type t() :: %ExOpenAI.Components.ResponseContentPartDoneEvent{ content_index: integer(), item_id: String.t(), output_index: integer(), part: ExOpenAI.Components.OutputContent.t(), sequence_number: integer(), type: :"response.content_part.done" }