View Source ExOpenAI.Components.ResponseFileSearchCallInProgressEvent (ex_openai.ex v2.0.0-beta2)
Emitted when a file search call is initiated.
Fields
:item_id- required -String.t()
The ID of the output item that the file search call is initiated.:output_index- required -integer()
The index of the output item that the file search call is initiated.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.file_search_call.in_progress"
The type of the event. Alwaysresponse.file_search_call.in_progress.
Allowed values:"response.file_search_call.in_progress"