View Source ExOpenAI.Components.ResponseMCPCallArgumentsDeltaEvent (ex_openai.ex v2.0.0-beta2)
Emitted when there is a delta (partial update) to the arguments of an MCP tool call.
Fields
:delta- required -String.t()
A JSON string containing the partial update to the arguments for the MCP tool call.:item_id- required -String.t()
The unique identifier of the MCP tool call item being processed.:output_index- required -integer()
The index of the output item in the response's output array.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.mcp_call_arguments.delta"
The type of the event. Always 'response.mcp_call_arguments.delta'.
Allowed values:"response.mcp_call_arguments.delta"