View Source ExOpenAI.Components.ResponseOutputTextAnnotationAddedEvent (ex_openai.ex v2.0.0-beta2)
Emitted when an annotation is added to output text content.
Fields
:annotation- required -map()
The annotation object being added. (See annotation schema for details.):annotation_index- required -integer()
The index of the annotation within the content part.:content_index- required -integer()
The index of the content part within the output item.:item_id- required -String.t()
The unique identifier of the item to which the annotation is being added.:output_index- required -integer()
The index of the output item in the response's output array.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.output_text.annotation.added"
The type of the event. Always 'response.output_text.annotation.added'.
Allowed values:"response.output_text.annotation.added"