View Source ExOpenAI.Components.ResponseReasoningTextDeltaEvent (ex_openai.ex v2.0.0-beta2)
Emitted when a delta is added to a reasoning text.
Fields
:content_index- required -integer()
The index of the reasoning content part this delta is associated with.:delta- required -String.t()
The text delta that was added to the reasoning content.:item_id- required -String.t()
The ID of the item this reasoning text delta is associated with.:output_index- required -integer()
The index of the output item this reasoning text delta is associated with.:sequence_number- required -integer()
The sequence number of this event.:type- required -:"response.reasoning_text.delta"
The type of the event. Alwaysresponse.reasoning_text.delta.
Allowed values:"response.reasoning_text.delta"