View Source ExOpenAI.Components.RunStepDeltaObject (ex_openai.ex v2.0.0-beta2)
Represents a run step delta i.e. any changed fields on a run step during streaming.
Fields
:delta- required -{:%{}, [], [{{:optional, [], [:step_details]}, {:map, [], []}}]}
The delta containing the fields that have changed on the run step.:id- required -String.t()
The identifier of the run step, which can be referenced in API endpoints.:object- required -:"thread.run.step.delta"
The object type, which is alwaysthread.run.step.delta.
Allowed values:"thread.run.step.delta"