View Source ExOpenAI.Components.RunStepDeltaStepDetailsToolCallsCodeObject (ex_openai.ex v2.0.0-beta2)
Details of the Code Interpreter tool call the run step was involved in.
Fields
:code_interpreter- optional -{:%{}, [], [{{:optional, [], [:input]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:optional, [], [:outputs]}, {:list, [], [{:map, [], []}]}}]}
The Code Interpreter tool call definition.:id- optional -String.t()
The ID of the tool call.:index- required -integer()
The index of the tool call in the tool calls array.:type- required -:code_interpreter
The type of tool call. This is always going to becode_interpreterfor this type of tool call.
Allowed values:"code_interpreter"