View Source ExOpenAI.Components.RunStepDeltaStepDetailsToolCallsFileSearchObject (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema RunStepDeltaStepDetailsToolCallsFileSearchObject.
Fields
:file_search- required -map()
For now, this is always going to be an empty object.:id- optional -String.t()
The ID of the tool call object.:index- required -integer()
The index of the tool call in the tool calls array.:type- required -:file_search
The type of tool call. This is always going to befile_searchfor this type of tool call.
Allowed values:"file_search"