View Source ExOpenAI.Components.RunStepDetailsToolCallsCodeOutputLogsObject (ex_openai.ex v2.0.0-beta2)
Text output from the Code Interpreter tool call as part of a run step.
Fields
:logs- required -String.t()
The text output from the Code Interpreter tool call.:type- required -:logs
Alwayslogs.
Allowed values:"logs"
Summary
Types
@type t() :: %ExOpenAI.Components.RunStepDetailsToolCallsCodeOutputLogsObject{ logs: String.t(), type: :logs }