View Source ExOpenAI.Components.RunStepDetailsToolCallsObject (ex_openai.ex v2.0.0-beta2)
Details of the tool call.
Fields
:tool_calls- required -[ExOpenAI.Components.RunStepDetailsToolCallsCodeObject.t() | ExOpenAI.Components.RunStepDetailsToolCallsFileSearchObject.t() | ExOpenAI.Components.RunStepDetailsToolCallsFunctionObject.t()]
An array of tool calls the run step was involved in. These can be associated with one of three types of tools:code_interpreter,file_search, orfunction.:type- required -:tool_calls
Alwaystool_calls.
Allowed values:"tool_calls"
Summary
Types
@type t() :: %ExOpenAI.Components.RunStepDetailsToolCallsObject{ tool_calls: [ (ExOpenAI.Components.RunStepDetailsToolCallsCodeObject.t() | ExOpenAI.Components.RunStepDetailsToolCallsFileSearchObject.t()) | ExOpenAI.Components.RunStepDetailsToolCallsFunctionObject.t() ], type: :tool_calls }