View Source ExOpenAI.Components.RunToolCallObject (ex_openai.ex v2.0.0-beta2)
Tool call objects
Fields
:function- required -{:%{}, [], [{{:required, [], [:arguments]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}, {{:required, [], [:name]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}
The function definition.:id- required -String.t()
The ID of the tool call. This ID must be referenced when you submit the tool outputs in using the Submit tool outputs to run endpoint.:type- required -:function
The type of tool call the output is required for. For now, this is alwaysfunction.
Allowed values:"function"