View Source ExOpenAI.Components.ToolChoiceOptions (ex_openai.ex v2.0.0-beta2)
Controls which (if any) tool is called by the model.
none means the model will not call any tool and instead generates a message.
auto means the model can pick between generating a message or calling one or
more tools.
required means the model must call one or more tools.
Type
:none | :auto | :required
Allowed Values
"none", "auto", "required"
Summary
Types
@type t() :: (:none | :auto) | :required