View Source ExOpenAI.Components.ToolSearchOutputItemParam (ex_openai.ex v2.0.0-beta2)
Module for representing the OpenAI schema ToolSearchOutputItemParam.
Fields
:call_id- optional -String.t() | any():execution- optional -ExOpenAI.Components.ToolSearchExecutionType.t()
Whether tool search was executed by the server or by the client.:id- optional -String.t() | any():status- optional -ExOpenAI.Components.FunctionCallItemStatus.t() | any():tools- required -[ExOpenAI.Components.Tool.t()]
The loaded tool definitions returned by the tool search output.:type- required -:tool_search_output
The item type. Alwaystool_search_output.
Allowed values:"tool_search_output"
Default:"tool_search_output"
Summary
Types
@type t() :: %ExOpenAI.Components.ToolSearchOutputItemParam{ call_id: (String.t() | any()) | nil, execution: ExOpenAI.Components.ToolSearchExecutionType.t() | nil, id: (String.t() | any()) | nil, status: (ExOpenAI.Components.FunctionCallItemStatus.t() | any()) | nil, tools: [ExOpenAI.Components.Tool.t()], type: :tool_search_output }