View Source ExOpenAI.Components.TranscriptTextDeltaEvent (ex_openai.ex v2.0.0-beta2)
Emitted when there is an additional text delta. This is also the first event emitted when the transcription starts. Only emitted when you create a transcription with the Stream parameter set to true.
Fields
:delta- required -String.t()
The text delta that was additionally transcribed.:logprobs- optional -[{:%{}, [], [{{:optional, [], [:bytes]}, {:list, [], [{:integer, [], []}]}}, {{:optional, [], [:logprob]}, {:number, [], []}}, {{:optional, [], [:token]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}]
The log probabilities of the delta. Only included if you create a transcription with theinclude[]parameter set tologprobs.:segment_id- optional -String.t()
Identifier of the diarized segment that this delta belongs to. Only present when usinggpt-4o-transcribe-diarize.:type- required -:"transcript.text.delta"
The type of the event. Alwaystranscript.text.delta.
Allowed values:"transcript.text.delta"