View Source ExOpenAI.Components.TranscriptTextDoneEvent (ex_openai.ex v2.0.0-beta2)
Emitted when the transcription is complete. Contains the complete transcription text. Only emitted when you create a transcription with the Stream parameter set to true.
Fields
:logprobs- optional -[{:%{}, [], [{{:optional, [], [:bytes]}, {:list, [], [{:integer, [], []}]}}, {{:optional, [], [:logprob]}, {:number, [], []}}, {{:optional, [], [:token]}, {{:., [], [{:__aliases__, [alias: false], [:String]}, :t]}, [], []}}]}]
The log probabilities of the individual tokens in the transcription. Only included if you create a transcription with theinclude[]parameter set tologprobs.:text- required -String.t()
The text that was transcribed.:type- required -:"transcript.text.done"
The type of the event. Alwaystranscript.text.done.
Allowed values:"transcript.text.done":usage- optional -ExOpenAI.Components.TranscriptTextUsageTokens.t()
Summary
Types
@type t() :: %ExOpenAI.Components.TranscriptTextDoneEvent{ logprobs: [ %{ optional(:bytes) => [integer()], optional(:logprob) => number(), optional(:token) => String.t() } ] | nil, text: String.t(), type: :"transcript.text.done", usage: ExOpenAI.Components.TranscriptTextUsageTokens.t() | nil }