View Source ExOpenAI.Components.TruncationObject (ex_openai.ex v2.0.0-beta2)
Controls for how a thread will be truncated prior to the run. Use this to control the initial context window of the run.
Fields
:last_messages- optional -integer() | any():type- required -:auto | :last_messages
The truncation strategy to use for the thread. The default isauto. If set tolast_messages, the thread will be truncated to the n most recent messages in the thread. When set toauto, messages in the middle of the thread will be dropped to fit the context length of the model,max_prompt_tokens.
Allowed values:"auto","last_messages"