View Source ExOpenAI.Components.UploadPart (ex_openai.ex v2.0.0-beta2)
The upload Part represents a chunk of bytes we can add to an Upload object.
Fields
:created_at- required -integer()
The Unix timestamp (in seconds) for when the Part was created.:id- required -String.t()
The upload Part unique identifier, which can be referenced in API endpoints.:object- required -:"upload.part"
The object type, which is alwaysupload.part.
Allowed values:"upload.part":upload_id- required -String.t()
The ID of the Upload object that this Part was added to.