View Source ExOpenAI.Components.WebSearchLocation (ex_openai.ex v2.0.0-beta2)
Approximate location parameters for the search.
Fields
:city- optional -String.t()
Free text input for the city of the user, e.g.San Francisco.:country- optional -String.t()
The two-letter ISO country code of the user, e.g.US.:region- optional -String.t()
Free text input for the region of the user, e.g.California.:timezone- optional -String.t()
The IANA timezone of the user, e.g.America/Los_Angeles.