View Source ExOpenAI.Components.WebSearchToolCall (ex_openai.ex v2.0.0-beta2)
The results of a web search tool call. See the web search guide for more information.
Fields
:action- required -map()
An object describing the specific action taken in this web search call. Includes details on how the model used the web (search, open_page, find_in_page).:id- required -String.t()
The unique ID of the web search tool call.:status- required -:in_progress | :searching | :completed | :failed
The status of the web search tool call.
Allowed values:"in_progress","searching","completed","failed":type- required -:web_search_call
The type of the web search tool call. Alwaysweb_search_call.
Allowed values:"web_search_call"